@@ -18,7 +18,7 @@
 #include <qapplication.h>
 #include "controlobjectthread.h"
 #include "controlobject.h"
-#include "engineobject.h"
+
 
 QWaitCondition ControlObjectThread::m_sqWait;
 QMutex ControlObjectThread::m_sqMutex;
@@ -70,24 +70,30 @@ bool ControlObjectThread::setExtern(double v)
 {
     bool result = false;
 
-    if ( m_sqMutex.tryLock() )
-    {
-        if( m_dataMutex.tryLock() )
-        {
-            m_sqQueue.enqueue(this);
-            m_dValue = v;
-            
-            m_dataMutex.unlock();
-            m_sqMutex.unlock();
-            
-            result = true;
-        }
-        else
-        {
-            m_sqMutex.unlock();
-        }
+    if (m_dataMutex.tryLock()) {
+        m_dValue = v;
+        result = true;
+        m_dataMutex.unlock();
     }
 
+    // if ( m_sqMutex.tryLock() )
+    // {
+    //     if( m_dataMutex.tryLock() )
+    //     {
+    //         m_sqQueue.enqueue(this);
+    //         m_dValue = v;
+            
+    //         m_dataMutex.unlock();
+    //         m_sqMutex.unlock();
+            
+    //         result = true;
+    //     }
+    //     else
+    //     {
+    //         m_sqMutex.unlock();
+    //     }
+    // }
+
     return result;
 }
 
@@ -146,4 +152,4 @@ void ControlObjectThread::slotParentDead()
 ControlObject* ControlObjectThread::getControlObject() 
 {
    return m_pControlObject;
-}
\ No newline at end of file
+}
