@@ -27,9 +27,9 @@
 #include "controlobject.h"
 #include "controlobjectthreadmain.h"
 #include "mixxxview.h"
-#include "wnumberpos.h"
-#include "wnumberbpm.h"
-#include "enginebuffer.h"
+#include "widget/wnumberpos.h"
+#include "widget/wnumberbpm.h"
+#include "engine/enginebuffer.h"
 
 DlgPrefControls::DlgPrefControls(QWidget * parent, MixxxView * pView, MixxxApp * mixxx, ConfigObject<ConfigValue> * pConfig) :  QWidget(parent), Ui::DlgPrefControlsDlg()
 {
@@ -143,23 +143,35 @@ DlgPrefControls::DlgPrefControls(QWidget * parent, MixxxView * pView, MixxxApp *
     // Default Cue Behavior
     //
     
-    m_pControlCueDefault1 = new ControlObjectThreadMain(ControlObject::getControl(ConfigKey("[Channel1]","cue_simple")));
-    m_pControlCueDefault2 = new ControlObjectThreadMain(ControlObject::getControl(ConfigKey("[Channel2]","cue_simple")));
+    m_pControlCueDefault1 = new ControlObjectThreadMain(ControlObject::getControl(ConfigKey("[Channel1]","cue_mode")));
+    m_pControlCueDefault2 = new ControlObjectThreadMain(ControlObject::getControl(ConfigKey("[Channel2]","cue_mode")));
     
     // Set default value in config file and control objects, if not present
-    if (m_pConfig->getValueString(ConfigKey("[Controls]","CueDefault")).length() == 0) {
+    QString cueDefault = m_pConfig->getValueString(ConfigKey("[Controls]","CueDefault"));
+    if(cueDefault.length() == 0) {
         m_pConfig->set(ConfigKey("[Controls]","CueDefault"), ConfigValue(0));
-        m_pControlCueDefault1->slotSet(0);
-        m_pControlCueDefault1->slotSet(0);
+        cueDefault = "0";
     }
+    int cueDefaultValue = cueDefault.toInt();
+
+    m_pControlCueDefault1->slotSet(cueDefaultValue);
+    m_pControlCueDefault2->slotSet(cueDefaultValue);
     
     // Update combo box
     ComboBoxCueDefault->addItem("CDJ Mode");
     ComboBoxCueDefault->addItem("Simple");
     ComboBoxCueDefault->setCurrentIndex(m_pConfig->getValueString(ConfigKey("[Controls]","CueDefault")).toInt());
-    
+   
     connect(ComboBoxCueDefault,   SIGNAL(activated(int)), this, SLOT(slotSetCueDefault(int)));
-    
+
+    //Cue recall
+    ComboBoxCueRecall->addItem(tr("On"));
+    ComboBoxCueRecall->addItem(tr("Off"));
+    ComboBoxCueRecall->setCurrentIndex(m_pConfig->getValueString(ConfigKey("[Controls]", "CueRecall")).toInt());
+    //NOTE: for CueRecall, 0 means ON....
+    connect(ComboBoxCueRecall, SIGNAL(activated(int)), this, SLOT(slotSetCueRecall(int)));
+
+
 // #ifndef QT3_SUPPORT
 //     const QFileInfoList * list = dir.entryInfoList();
 //     if (list!=0)
@@ -332,7 +344,10 @@ void DlgPrefControls::slotSetRateDir(int)
 void DlgPrefControls::slotSetVisuals(int)
 {
     m_pConfig->set(ConfigKey("[Controls]","Visuals"), ConfigValue(ComboBoxVisuals->currentIndex()));
-    textLabel->setText(tr("Restart Mixxx before the change of visuals will take effect."));
+    QMessageBox::information(this, tr("Information"), //make the fact that you have to restart mixxx more obvious
+    //textLabel->setText(
+      tr("Restart Mixxx before the change of visuals will take effect.")
+      );
 }
 
 void DlgPrefControls::slotSetCueDefault(int)
@@ -342,6 +357,11 @@ void DlgPrefControls::slotSetCueDefault(int)
     m_pControlCueDefault2->slotSet(ComboBoxCueDefault->currentIndex());
 }
 
+void DlgPrefControls::slotSetCueRecall(int)
+{
+    m_pConfig->set(ConfigKey("[Controls]","CueRecall"), ConfigValue(ComboBoxCueRecall->currentIndex()));
+}
+
 void DlgPrefControls::slotSetScaleBpm(int)
 {
     m_pConfig->set(ConfigKey("[Controls]","ScaleBpm"), ConfigValue((ComboBoxScaleBpm->currentIndex()+1)%2));
@@ -363,7 +383,9 @@ void DlgPrefControls::slotSetTooltips(int)
     //to refresh it during each Tooltip event (I think), which is why we require a restart.
 
     
-    textLabel->setText(tr("Mixxx must be restarted before the changes will take effect."));
+    QMessageBox::information(this, tr("Information"), //make the fact that you have to restart mixxx more obvious
+    //textLabel->setText(
+      tr("Mixxx must be restarted before the changes will take effect."));
     
 
 //    if (ComboBoxTooltips->currentIndex()==0)
