@@ -31,11 +31,13 @@ class QStackedWidget;
 
 class MixxxApp;
 class MixxxView;
+class PlayerProxy;
 class SoundManager;
 class Track;
 class DlgPrefSound;
-class DlgPrefMidi;
+class DlgPrefMidiBindings;
 class DlgPrefPlaylist;
+class DlgPrefNoMidi;
 class DlgPrefControls;
 class DlgPrefEQ;
 class DlgPrefCrossfader;
@@ -44,6 +46,7 @@ class DlgPrefBpm;
 class DlgPrefVinyl;
 class DlgPrefShoutcast;
 class PowerMate;
+class MidiObject;
 
 /**
   *@author Tue & Ken Haste Andersen
@@ -53,15 +56,16 @@ class DlgPreferences : public QDialog, public Ui::DlgPreferencesDlg
 {
     Q_OBJECT
 public:
-    DlgPreferences(MixxxApp *mixxx, MixxxView *view,
-                   SoundManager *soundman,
-                   Track *track, ConfigObject<ConfigValue> *config);
+    DlgPreferences(MixxxApp *mixxx, MixxxView *view, SoundManager *soundman,
+    		Track *track, MidiObject * midi, ConfigObject<ConfigValue> *config);
     ~DlgPreferences();
     void createIcons();
 public slots:
-    void slotUpdate();
+    void slotShow();
+    void slotHide();
+    void rescanMidi();
     void slotApply();
-    void changePage(QListWidgetItem *current, QListWidgetItem *previous);
+    void changePage(QTreeWidgetItem *current, QTreeWidgetItem *previous);
     void showVinylControlPage();
 signals:
     void closeDlg();
@@ -69,9 +73,12 @@ signals:
 protected:
     bool eventFilter(QObject *, QEvent *);
 private:
+    void destroyMidiWidgets();
+    void setupMidiWidgets();
     DlgPrefSound *wsound;
-    DlgPrefMidi *wmidi;
+    QList<DlgPrefMidiBindings*> wmidiBindingsForDevice;
     DlgPrefPlaylist *wplaylist;
+    DlgPrefNoMidi *wNoMidi;
     DlgPrefControls *wcontrols;
     DlgPrefEQ *weq;
     DlgPrefCrossfader *wcrossfader;
@@ -80,9 +87,22 @@ private:
     DlgPrefVinyl *wvinylcontrol;
     DlgPrefShoutcast *wshoutcast;
 
+	QTreeWidgetItem* m_pSoundButton;    
+	QTreeWidgetItem* m_pPlaylistButton;    
+	QTreeWidgetItem* m_pControlsButton;    
+	QTreeWidgetItem* m_pEqButton;    
+	QTreeWidgetItem* m_pCrossfaderButton;    
+	QTreeWidgetItem* m_pRecordingButton;    
+	QTreeWidgetItem* m_pBPMdetectButton;    
+	QTreeWidgetItem* m_pVinylControlButton;    
+	QTreeWidgetItem* m_pShoutcastButton;    
+    QTreeWidgetItem* m_pMIDITreeItem;
+    QList<QTreeWidgetItem*> m_midiBindingsButtons;
+
     ConfigObject<ConfigValue> *config;
     MixxxApp *m_pMixxx;
     Track* m_pTrack;
+    MidiObject* m_pMidiObject;
 };
 
 #endif
