@@ -31,13 +31,13 @@
 #include "mixxx.h"
 #include "qpixmap.h"
 #include "qsplashscreen.h"
-#include "log.h"
+#include "errordialog.h"
 
 #ifdef __LADSPA__
-#include <ladspaloader.h>
+#include <ladspa/ladspaloader.h>
 #endif
 
-#ifdef Q_WS_WIN
+#ifdef __WINDOWS__
 #ifdef DEBUGCONSOLE
 #include <io.h> // Debug Console
 #include <windows.h>
@@ -64,17 +64,23 @@ void InitDebugConsole() { // Open a Debug Console so we can printf
     }
 }
 #endif // DEBUGCONSOLE
-#endif // Q_WS_WIN
+#endif // __WINDOWS__
 
 QApplication * a;
 
+QStringList plugin_paths; //yes this is global. sometimes global is good.
+ErrorDialog *dialogHelper; //= new ErrorDialog();   // allows threads to show error dialogs
+
 void qInitImages_mixxx();
 
 void MessageOutput( QtMsgType type, const char * msg )
 {
+    static QMutex mutex;
+    QMutexLocker locker(&mutex);
+
     switch ( type ) {
     case QtDebugMsg:
-#ifdef Q_WS_WIN
+#ifdef __WINDOWS__
         if (strstr(msg, "doneCurrent")) {
             break;
         }
@@ -98,8 +104,12 @@ void MessageOutput( QtMsgType type, const char * msg )
 
 QFile Logfile; // global logfile variable
 
+
 void MessageToLogfile( QtMsgType type, const char * msg )
 {
+    static QMutex mutex;
+    QMutexLocker locker(&mutex);
+    
     Q3TextStream Log( &Logfile );
     switch ( type ) {
     case QtDebugMsg:
@@ -107,9 +117,9 @@ void MessageToLogfile( QtMsgType type, const char * msg )
         break;
     case QtWarningMsg:
         Log << "Warning: " << msg << "\n";
-        a->lock();
+        //a->lock(); //this doesn't do anything in Qt4
         QMessageBox::warning(0, "Mixxx", msg);
-        a->unlock();
+        //a->unlock();
         break;
     case QtCriticalMsg:
         fprintf( stderr, "Critical: %s\n", msg );
@@ -125,60 +135,99 @@ void MessageToLogfile( QtMsgType type, const char * msg )
 }
 
 
+/* Debug message handler which outputs to both a logfile and a
+ * and prepends the thread the message came from too.
+ *
+ *
+ */
+void MessageHandler( QtMsgType type, const char * input )
+{
+    static QMutex mutex;
+    QMutexLocker locker(&mutex);
+    QString tmp = QString("[%1]: %2").arg(QThread::currentThread()->objectName()).arg(input);
+    QByteArray ba = tmp.toLocal8Bit(); //necessary inner step to avoid memory corruption (otherwise the QByteArray is destroyed at the end of the next line which is BAD NEWS BEARS)
+    const char* s = ba.constData();
+    
+    
+    if(!Logfile.isOpen())
+    {
+    Logfile.setFileName("mixxx.log"); //XXX will there ever be a case that we can't write to our current working directory?
+     
+#ifdef QT3_SUPPORT
+    Logfile.open(QIODevice::WriteOnly | QIODevice::Text);
+#else
+    Logfile.open(IO_WriteOnly | IO_Translate);
+#endif
+    }
+      
+    Q3TextStream Log( &Logfile );	
+    
+    switch ( type ) {
+    case QtDebugMsg:
+#ifdef __WINDOWS__  //wtf? -kousu 2/2009
+        if (strstr(input, "doneCurrent")) {
+            break;
+        }
+#endif
+        fprintf( stderr, "Debug: %s\n", s );
+        Log << "Debug: " << s << "\n";
+        break;
+    case QtWarningMsg:
+        fprintf( stderr, "Warning: %s\n", s);
+        Log << "Warning: " << s << "\n";
+//         QMessageBox::warning(0, "Mixxx", input);
+        dialogHelper->requestErrorDialog(0,input);
+        break;
+    case QtCriticalMsg:
+        fprintf( stderr, "Critical: %s\n", s );
+        Log << "Critical: " << s << "\n";
+//         QMessageBox::critical(0, "Mixxx", input);
+        dialogHelper->requestErrorDialog(1,input);
+//         exit(-1);
+        break; //NOTREACHED(?)
+    case QtFatalMsg:
+        fprintf( stderr, "Fatal: %s\n", s );
+        Log << "Fatal: " << s << "\n";
+//         QMessageBox::critical(0, "Mixxx", input);
+        dialogHelper->requestErrorDialog(1,input);
+        abort();
+        break; //NOTREACHED
+    }
+    Logfile.flush();
+}
+
+
 int main(int argc, char * argv[])
 {
     // Check if an instance of Mixxx is already running
 
 
-#ifdef Q_WS_WIN
-    // For windows write all debug messages to a logfile:
-    Logfile.setName( "mixxx.log" );
-  #ifndef QT3_SUPPORT
-    Logfile.open(IO_WriteOnly | IO_Translate);
-  #else
-    Logfile.open(QIODevice::WriteOnly | QIODevice::Text);
-  #endif
+//it seems like this code should be inline in MessageHandler() but for some reason having it there corrupts the messages sometimes -kousu 2/2009
+	
+
+#ifdef __WINDOWS__
   #ifdef DEBUGCONSOLE
     InitDebugConsole();
-    qInstallMsgHandler( MessageOutput );
-  #else
-    qInstallMsgHandler( MessageToLogfile );
   #endif
-#else
-    // For others, write to the console:
-    qInstallMsgHandler( MessageOutput );
 #endif
+   dialogHelper = new ErrorDialog(); 
 
+    qInstallMsgHandler( MessageHandler );
+
+    QThread::currentThread()->setObjectName("Main");
     a = new QApplication(argc, argv);
 
-//Hack to make QT4 find the plugins when packaging in the Mixxx.app bundle on OS X.
-//See http://doc.trolltech.com/4.3/deployment-mac.html for details.
-#ifdef __MACX__
-    QDir dir(QApplication::applicationDirPath());
-    dir.cdUp();
-    dir.cd("plugins");
-    QApplication::setLibraryPaths(QStringList(dir.absolutePath()));
-#endif
 
 
 #ifdef __LADSPA__
     //LADSPALoader ladspaloader;
 #endif
 
-    // Show splash
-    QSplashScreen * pSplash = 0;
-    /*
-       QPixmap pixmap("splash.png");
-       pSplash = new QSplashScreen(pixmap);
-       pSplash->show();
-       pSplash->message("Loading...",Qt::AlignLeft|Qt::AlignBottom);
-     */
-
     QTranslator tor( 0 );
     // set the location where your .qm files are in load() below as the last parameter instead of "."
     // for development, use "/" to use the english original as
     // .qm files are stored in the base project directory.
-    tor.load( QString("mixxx.") + QTextCodec::locale(), "." );
+    tor.load( QString("mixxx.") + QLocale::system().name(), "." );
     a->installTranslator( &tor );
 
     // Check if one of the command line arguments is "--no-visuals"
@@ -191,14 +240,8 @@ int main(int argc, char * argv[])
     struct CmdlineArgs args;
     args.bStartInFullscreen = false; //Initialize vars
 
-    QString qLogFileName = "";
     for (int i=0; i<argc; ++i)
     {
-        if (argv[i]==QString("--log"))
-        {
-            args.qLogFileName = argv[i+1];
-            i++;
-        }
         if (argv[i]==QString("-f") || argv[i]==QString("--f"))
         {
             args.bStartInFullscreen = true;
@@ -206,21 +249,75 @@ int main(int argc, char * argv[])
         else
             args.qlMusicFiles += argv[i];
     }
-
-    MixxxApp * mixxx=new MixxxApp(a, args, pSplash);
     
-    a->setMainWidget(mixxx);
+    
+    // set up the plugin paths...
+    qDebug() << "Setting up plugin paths...";
+    /*
+    plugin_paths = QStringList();
+    QString ladspaPath = QString(getenv("LADSPA_PATH"));
 
-    mixxx->show();
-
-    if (pSplash)
+    if (!ladspaPath.isEmpty())
     {
-        pSplash->finish(mixxx);
-        delete pSplash;
+        // get the list of directories containing LADSPA plugins
+#ifdef __WINDOWS__
+        //paths.ladspaPath.split(';');
+#else  //this doesn't work, I think we need to iterate over the splitting to do it properly
+        //paths = ladspaPath.split(':');
+#endif
     }
+    else
+    {
+        // add default path if LADSPA_PATH is not set
+#ifdef __LINUX__
+        plugin_paths.push_back ("/usr/lib/ladspa/");
+        plugin_paths.push_back ("/usr/lib64/ladspa/");
+#elif __APPLE__
+      QDir dir(a->applicationDirPath());
+     dir.cdUp();
+     dir.cd("PlugIns");
+         plugin_paths.push_back ("/Library/Audio/Plug-ins/LADSPA");
+         plugin_paths.push_back (dir.absolutePath()); //ladspa_plugins directory in Mixxx.app bundle //XXX work in QApplication::appdir()
+#elif __WINDOWS__
+        // not tested yet but should work:
+        QString programFiles = QString(getenv("ProgramFiles"));
+         plugin_paths.push_back (programFiles+"\\LADSPA Plugins");
+         plugin_paths.push_back (programFiles+"\\Audacity\\Plug-Ins");
+#endif
+    }
+    */
+    qDebug() << "...done.";
+    
+#ifdef __APPLE__
+     qDebug() << "setting Qt's plugin seach path (on OS X)";
+     QDir dir(QApplication::applicationDirPath());
+     dir.cdUp();
+     dir.cd("PlugIns");
+     QApplication::addLibraryPath(dir.absolutePath());
+     //qDebug() << dir.absolutePath() << QApplication::applicationDirPath();
+#endif
 
-    int result = a->exec();
+    MixxxApp * mixxx=new MixxxApp(a, args);
+
+    //a->setMainWidget(mixxx);
+    a -> connect( a, SIGNAL(lastWindowClosed()), a, SLOT(quit()) );
+    
+    int result = -1;
+
+    if (!dialogHelper->checkError()) {
+        qDebug() << "Displaying mixxx";
+        mixxx->show();
+    
+        qDebug() << "Running Mixxx";
+        result = a->exec();
+    }
+    
     delete mixxx;
+    
+    if(Logfile.isOpen())
+	Logfile.close();
+    
+    //delete plugin_paths;
     return result;
 }
 
