@@ -25,8 +25,8 @@
   */
 
 class MidiObjectNull : public MidiObject  {
-public: 
-    MidiObjectNull(ConfigObject<ConfigValueMidi> *c, QString device);
+public:
+    MidiObjectNull();
     ~MidiObjectNull();
     void devOpen(QString device);
     void devClose();
