@@ -65,6 +65,8 @@ MidiObjectOSS::MidiObjectOSS(QString device) : MidiObject(device)
 
 MidiObjectOSS::~MidiObjectOSS()
 {
+    stop();
+    shutdown(); // From parent MidiObject
     // Close device and delete buffer
     devClose();
     delete [] buffer;
@@ -101,6 +103,15 @@ void MidiObjectOSS::stop()
 
 void MidiObjectOSS::run()
 {
+    unsigned static id = 0; //the id of this thread, for debugging purposes //XXX copypasta (should factor this out somehow), -kousu 2/2009
+    QThread::currentThread()->setObjectName(QString("MidiObjectOSS %1").arg(++id));
+    
+    qDebug() << QString("MidiObjectOSS: Thread ID=%1").arg(this->thread()->currentThreadId(),0,16);
+
+#ifdef __MIDISCRIPT__
+    MidiObject::run();
+#endif
+
     requestStop=false;
     while(requestStop==false)
     {
