@@ -19,33 +19,37 @@
 #include <QtCore>
 #include <QtGui>
 
-#include "wknob.h"
-#include "wslider.h"
-#include "wpushbutton.h"
-#include "woverview.h"
+#include "widget/wknob.h"
+#include "widget/wslider.h"
+#include "widget/wpushbutton.h"
+#include "widget/woverview.h"
 #include "mixxx.h"
 #include "controlnull.h"
 #include "readerextractwave.h"
 #include "controlpotmeter.h"
 #include "controlobjectthreadmain.h"
 #include "reader.h"
-#include "enginebuffer.h"
-#include "enginevumeter.h"
+#include "engine/enginebuffer.h"
+#include "analyserqueue.h"
+#include "engine/enginevumeter.h"
 #include "track.h"
 #include "trackcollection.h"
 #include "trackinfoobject.h"
-#include "mixxxsocketserver.h"
-#include "mixxxmenuplaylists.h"
-#include "wavesummary.h"
-#include "bpmdetector.h"
-#include "log.h"
+#include "bpm/bpmdetector.h"
 #include "dlgabout.h"
+#include "waveform/waveformrenderer.h"
 
 #include "soundmanager.h"
 #include "defs_urls.h"
 #include "defs_audiofiles.h"
+#include "mididevicehandler.h"
 #include "recording/defs_recording.h"
 
+#include "defs_version.h"
+#include "upgrade.h"
+
+#include "build.h" //#defines of details of the build set up (flags, repo number, etc). This isn't a real file, SConscript generates it and it probably gets placed in $PLATFORM_build/. By including this file here and only here we make sure that updating src or changing the build flags doesn't force a rebuild of everything
+
 #ifdef __IPOD__
 #include "wtracktableview.h"
 #include "gpod/itdb.h"
@@ -64,99 +68,72 @@ extern "C" void crashDlg()
 }
 
 
-MixxxApp::MixxxApp(QApplication * a, struct CmdlineArgs args, QSplashScreen * pSplash)
+MixxxApp::MixxxApp(QApplication * a, struct CmdlineArgs args)
 {
     app = a;
-
-    #include ".mixxx_version.svn" // #define BUILD_REV = "<svn rev number>"
-    QString buildRevision = "";
+    
+    QString buildRevision, buildFlags;
     #ifdef BUILD_REV
       buildRevision = BUILD_REV;
     #endif
-    #include ".mixxx_flags.svn" // #define BUILD_FLAGS = "<flags>"
-    QString buildFlags = "";
+    
     #ifdef BUILD_FLAGS
       buildFlags = BUILD_FLAGS;
     #endif
-    if (buildRevision.trimmed().length() > 0)
-        if (buildFlags.trimmed().length() > 0) buildRevision = "(svn " + buildRevision + "; built on: " + __DATE__ + " @ " + __TIME__ + "; flags: " + buildFlags.trimmed() + ") ";
-        else buildRevision = "(svn " + buildRevision + "; built on: " + __DATE__ + " @ " + __TIME__ + ") ";
-
+    
+    if (buildRevision.trimmed().length() > 0) {
+        if (buildFlags.trimmed().length() > 0)
+            buildRevision = "(bzr r" + buildRevision + "; built on: " + __DATE__ + " @ " + __TIME__ + "; flags: " + buildFlags.trimmed() + ") ";
+        else
+            buildRevision = "(bzr r" + buildRevision + "; built on: " + __DATE__ + " @ " + __TIME__ + ") ";
+    }
+    
     qDebug() << "Mixxx" << VERSION << buildRevision << "is starting...";
     setWindowTitle(tr("Mixxx " VERSION));
-#ifdef __MACX__
-    setWindowIcon(QIcon(":icon.svg"));
-#else
-    setWindowIcon(QIcon(":icon.svg"));
-    //setWindowIcon(QIcon(":iconsmall.png")); //This is a smaller 16x16 icon, looks cleaner...
-#endif
+    setWindowIcon(QIcon(":/images/icon.svg"));
 
     //Reset pointer to players
     soundmanager = 0;
     m_pTrack = 0;
     prefDlg = 0;
-
-    // Read the config file from home directory
-    config = new ConfigObject<ConfigValue>(QDir::homePath().append("/").append(SETTINGS_FILE));
+    midi = 0;
+    
+    // Check to see if this is the first time this version of Mixxx is run after an upgrade and make any needed changes.
+    config = versionUpgrade();  // This static function is located in upgrade.cpp
     QString qConfigPath = config->getConfigPath();
 
 #ifdef __C_METRICS__
-	//Initialize Case Metrics if User is OK with that
-	int fuserAgreeToDataCollection = false;
-	if(config->getValueString(ConfigKey("[User Experience]","AgreedToUserExperienceProgram")) == QString("yes"))
-		fuserAgreeToDataCollection = true;
-	else if(config->getValueString(ConfigKey("[User Experience]","AgreedToUserExperienceProgram")) != QString("no"))
-	{
-		while(1)
-		{
-			fuserAgreeToDataCollection = QMessageBox::question(this, "Mixxx", "Mixxx's development is driven by community feedback.  At your discretion, Mixxx can automatically send data on your user experience back to the developers. Would you like to help us make Mixxx better by enabling this feature?", "Yes", "No", "Privacy Policy", 0, -1);
-			if(fuserAgreeToDataCollection == 0)
-			{
-				fuserAgreeToDataCollection = true;
-				config->set(ConfigKey("[User Experience]","AgreedToUserExperienceProgram"), ConfigValue(QString("yes")));
-				break;
-			}
-			else if(fuserAgreeToDataCollection == 1)
-			{
-				fuserAgreeToDataCollection = false;
-				config->set(ConfigKey("[User Experience]","AgreedToUserExperienceProgram"), ConfigValue(QString("no")));
-				break;
-			}
-			else
-			{
-				//show privacy policy
-				QMessageBox::information(this, "Mixxx: Privacy Policy", "Mixxx's development is driven by community feedback.  In order to help improve future versions Mixxx will with your permission collect information on your hardware and usage of Mixxx.  This information will primarily be used to fix bugs, improve features, and determine the system requirements of later versions.  Additionally this information may be used in aggregate for statistical purposes.\n\nThe hardware information will include:\n\t- CPU model and features\n\t- Total/Available Amount of RAM\n\t- Available disk space\n\t- OS version\n\nYour usage information will include:\n\t- Settings/Preferences\n\t- Internal errors\n\t- Internal debugging messages\n\t- Performance statistics (average latency, CPU usage)\n\nThis information will not be used to personally identify you, contact you, advertise to you, or otherwise bother you in any way.\n");
-			}
-		}
-	}
-    //If the user agrees, attempt to load the user ID from the config file
-    const char *pstzUID;
-    bool fFreePstzUID = false;
-    if(fuserAgreeToDataCollection)
-    {
-        if(config->getValueString(ConfigKey("[User Experience]", "UID")) == QString(""))
-        {
-            pstzUID = cm_generate_userid();
-            fFreePstzUID = true;
-            if(pstzUID != NULL)
-            {
-                config->set(ConfigKey("[User Experience]", "UID"), ConfigValue(QString(pstzUID)));
-            }
-        }
-        else
-        {
-            pstzUID = config->getValueString(ConfigKey("[User Experience]", "UID")).ascii();
-        }
+    // Initialize Case Metrics if User is OK with that
+    QString metricsAgree = config->getValueString(ConfigKey("[User Experience]","AgreedToUserExperienceProgram"));
+
+    if (metricsAgree.isEmpty() || (metricsAgree != "yes" && metricsAgree != "no")) {
+      metricsAgree = "no";
+      int dlg = -1;
+      while (dlg != 0 && dlg != 1) {
+         dlg = QMessageBox::question(this, "Mixxx", "Mixxx's development is driven by community feedback.  At your discretion, Mixxx can automatically send data on your user experience back to the developers. Would you like to help us make Mixxx better by enabling this feature?", "Yes", "No", "Privacy Policy", 0, -1);
+  	 switch (dlg) {
+           case 0: metricsAgree = "yes";
+  	   case 1: break;
+           default: //show privacy policy
+	            QMessageBox::information(this, "Mixxx: Privacy Policy", "Mixxx's development is driven by community feedback.  In order to help improve future versions Mixxx will with your permission collect information on your hardware and usage of Mixxx.  This information will primarily be used to fix bugs, improve features, and determine the system requirements of later versions.  Additionally this information may be used in aggregate for statistical purposes.\n\nThe hardware information will include:\n\t- CPU model and features\n\t- Total/Available Amount of RAM\n\t- Available disk space\n\t- OS version\n\nYour usage information will include:\n\t- Settings/Preferences\n\t- Internal errors\n\t- Internal debugging messages\n\t- Performance statistics (average latency, CPU usage)\n\nThis information will not be used to personally identify you, contact you, advertise to you, or otherwise bother you in any way.\n");
+                    break;
+  	 }
+      }
+    }	
+    config->set(ConfigKey("[User Experience]","AgreedToUserExperienceProgram"), ConfigValue(metricsAgree));
+
+    // If the user agrees...
+    if(metricsAgree == "yes") {
+       // attempt to load the user ID from the config file
+       if ( config->getValueString(ConfigKey("[User Experience]", "UID")) == ""){
+         QString pUID = cm_generate_userid();
+         if(!pUID.isEmpty()) config->set(ConfigKey("[User Experience]", "UID"), ConfigValue(pUID));
+       }
     }
-
-	cm_init(100,20, fuserAgreeToDataCollection, MIXXCMETRICS_RELEASE_ID, pstzUID);
-
-    if(fFreePstzUID)
-        free((void*)pstzUID);
-
+    // Initialize cmetrics
+    cm_init(100,20, metricsAgree == "yes", MIXXCMETRICS_RELEASE_ID, config->getValueString(ConfigKey("[User Experience]", "UID")).ascii());
     cm_set_crash_dlg(crashDlg);
-	cm_writemsg_ascii(MIXXXCMETRICS_VERSION,
-	                  VERSION);
+    cm_writemsg_ascii(MIXXXCMETRICS_VERSION, VERSION);
 #endif
 
     // Store the path in the config database
@@ -165,18 +142,10 @@ MixxxApp::MixxxApp(QApplication * a, struct CmdlineArgs args, QSplashScreen * pS
     // Instantiate a ControlObject, and set static parent widget
     control = new ControlNull();
 
-
-    if (pSplash)
-        pSplash->showMessage("Initializing control devices...",Qt::AlignLeft|Qt::AlignBottom);
-
     // Read keyboard configuration and set kdbConfig object in WWidget
     kbdconfig = new ConfigObject<ConfigValueKbd>(QString(qConfigPath).append("keyboard/").append("Standard.kbd.cfg"));
     WWidget::setKeyboardConfig(kbdconfig);
 
-
-    if (pSplash)
-        pSplash->showMessage("Setting up sound engine...",Qt::AlignLeft|Qt::AlignBottom);
-
     // Sample rate used by Player object
     ControlObject * sr = new ControlObject(ConfigKey("[Master]","samplerate"));
     sr->set(44100.);
@@ -206,9 +175,6 @@ MixxxApp::MixxxApp(QApplication * a, struct CmdlineArgs args, QSplashScreen * pS
     soundmanager = new SoundManager(config, master);
     soundmanager->queryDevices();
 
-    if (pSplash)
-        pSplash->showMessage("Loading skin...",Qt::AlignLeft|Qt::AlignBottom);
-
     // Find path of skin
     QString qSkinPath = getSkinPath();
 
@@ -255,13 +221,10 @@ MixxxApp::MixxxApp(QApplication * a, struct CmdlineArgs args, QSplashScreen * pS
     QFile trackfile(config->getValueString(ConfigKey("[Playlist]","Listfile")));
     if ((config->getValueString(ConfigKey("[Playlist]","Listfile")).length()<1) || (!trackfile.exists()))
     {
-        config->set(ConfigKey("[Playlist]","Listfile"), QDir::homePath().append("/").append(TRACK_FILE));
+        config->set(ConfigKey("[Playlist]","Listfile"), QDir::homePath().append("/").append(SETTINGS_PATH).append(TRACK_FILE));
         config->Save();
     }
 
-    // Initialize wavefrom summary generation
-    m_pWaveSummary = new WaveSummary(config);
-
     // Intialize default BPM system values
     if(config->getValueString(ConfigKey("[BPM]","BPMRangeStart")).length()<1)
     {
@@ -278,14 +241,13 @@ MixxxApp::MixxxApp(QApplication * a, struct CmdlineArgs args, QSplashScreen * pS
         config->set(ConfigKey("[BPM]","AnalyzeEntireSong"),ConfigValue(1));
     }
 
-    // Initialize Bpm detection queue
-    m_pBpmDetector = new BpmDetector(config);
-
-    if (pSplash)
-        pSplash->showMessage("Loading song database...",Qt::AlignLeft|Qt::AlignBottom);
-
     // Initialize track object:
-    m_pTrack = new Track(config->getValueString(ConfigKey("[Playlist]","Listfile")), view, config, buffer1, buffer2, m_pWaveSummary, m_pBpmDetector);
+    m_pTrack = new Track(config->getValueString(ConfigKey("[Playlist]","Listfile")),
+                         view,
+                         config,
+                         buffer1,
+                         buffer2,
+                         AnalyserQueue::createDefaultAnalyserQueue(config));
 
     //WTreeItem::setTrack(m_pTrack);
     // Set up drag and drop to player visuals
@@ -295,10 +257,10 @@ MixxxApp::MixxxApp(QApplication * a, struct CmdlineArgs args, QSplashScreen * pS
         connect(view->m_pVisualCh2, SIGNAL(trackDropped(QString)), m_pTrack, SLOT(slotLoadPlayer2(QString)));
 
     // Ensure that visual receive updates when new tracks are loaded
-    if (view->m_pVisualCh1)
-        connect(m_pTrack, SIGNAL(newTrackPlayer1(TrackInfoObject *)), view->m_pVisualCh1, SLOT(slotNewTrack(TrackInfoObject *)));
-    if (view->m_pVisualCh2)
-        connect(m_pTrack, SIGNAL(newTrackPlayer2(TrackInfoObject *)), view->m_pVisualCh2, SLOT(slotNewTrack(TrackInfoObject *)));
+    if (view->m_pWaveformRendererCh1)
+        connect(m_pTrack, SIGNAL(newTrackPlayer1(TrackInfoObject *)), view->m_pWaveformRendererCh1, SLOT(slotNewTrack(TrackInfoObject *)));
+    if (view->m_pWaveformRendererCh2)
+        connect(m_pTrack, SIGNAL(newTrackPlayer2(TrackInfoObject *)), view->m_pWaveformRendererCh2, SLOT(slotNewTrack(TrackInfoObject *)));
 
 
 
@@ -306,8 +268,15 @@ MixxxApp::MixxxApp(QApplication * a, struct CmdlineArgs args, QSplashScreen * pS
     ControlObject::getControl(ConfigKey("[Channel1]","TrackEndMode"))->queueFromThread(config->getValueString(ConfigKey("[Controls]","TrackEndModeCh1")).toDouble());
     ControlObject::getControl(ConfigKey("[Channel2]","TrackEndMode"))->queueFromThread(config->getValueString(ConfigKey("[Controls]","TrackEndModeCh2")).toDouble());
 
+    // Initialise MIDI and open the MIDI device
+    MidiDeviceHandler * midiHandler = new MidiDeviceHandler();
+    midi = midiHandler->getMidiPtr();
+    QString midiDevice = config->getValueString(ConfigKey("[Midi]","Device"));
+    if (midiDevice != "")
+    	midi->devOpen(midiDevice);
+
     // Initialize preference dialog
-    prefDlg = new DlgPreferences(this, view, soundmanager, m_pTrack, config);
+    prefDlg = new DlgPreferences(this, view, soundmanager, m_pTrack, midi, config);
     prefDlg->setHidden(true);
 
 #ifdef __LADSPA__
@@ -316,20 +285,17 @@ MixxxApp::MixxxApp(QApplication * a, struct CmdlineArgs args, QSplashScreen * pS
 #endif
 
     // Try open player device If that fails, the preference panel is opened.
-    if (soundmanager->setupDevices() != 0)
+    while (soundmanager->setupDevices() != 0)
     {
 
 #ifdef __C_METRICS__
-	    cm_writemsg_ascii(MIXXXCMETRICS_FAILED_TO_OPEN_SNDDEVICE_AT_STARTUP,
-	                      "Mixxx failed to open audio device(s) on startup.");
+        cm_writemsg_ascii(MIXXXCMETRICS_FAILED_TO_OPEN_SNDDEVICE_AT_STARTUP,
+                          "Mixxx failed to open audio device(s) on startup.");
 #endif
 
-        QMessageBox::warning(this, tr("Mixxx"),
-                                   tr("Failed to open your audio device(s).\n"
-                                      "Please verify your selection in the preferences."),
-                                   QMessageBox::Ok,
-                                   QMessageBox::Ok);
-         prefDlg->show();
+        // Exit when we press the Exit button in the noSoundDlg dialog
+        if ( noSoundDlg() != 0 )
+            exit(0);
     }
 
     //setFocusPolicy(QWidget::StrongFocus);
@@ -348,11 +314,6 @@ MixxxApp::MixxxApp(QApplication * a, struct CmdlineArgs args, QSplashScreen * pS
         m_pTrack->slotLoadPlayer2(args.qlMusicFiles.at(2));
 #endif
 
-    // Set up socket interface
-//#ifndef __WIN__
-//    new MixxxSocketServer(m_pTrack);
-//#endif
-
     // Initialize visualization of temporal effects
     channel1->setEngineBuffer(buffer1);
     channel2->setEngineBuffer(buffer2);
@@ -371,11 +332,6 @@ MixxxApp::MixxxApp(QApplication * a, struct CmdlineArgs args, QSplashScreen * pS
     //This allows us to turn off tooltips.
     app->installEventFilter(this); //The eventfilter is located in this Mixxx class as a callback.
 
-    // Initialize the log if a log file name was given on the command line
-    Log *pLog = 0;
-    if (args.qLogFileName.length()>0)
-        pLog = new Log(args.qLogFileName, m_pTrack);
-
     //If we were told to start in fullscreen mode on the command-line, then turn on fullscreen mode.
     if (args.bStartInFullscreen)
         slotOptionsFullScreen(true);
@@ -404,9 +360,12 @@ MixxxApp::~MixxxApp()
       m_pTrack->m_qIPodPlaylist.clear();
     }
 #endif
+    qDebug() << "save config, " << qTime.elapsed();
+    config->Save();
 
     qDebug() << "Write track xml, " << qTime.elapsed();
     m_pTrack->writeXML(config->getValueString(ConfigKey("[Playlist]","Listfile")));
+	m_pTrack->appShuttingDown();
 
     qDebug() << "close soundmanager" << qTime.elapsed();
     soundmanager->closeDevices();
@@ -432,7 +391,9 @@ MixxxApp::~MixxxApp()
 
 //    qDebug() << "delete prefDlg";
 //    delete m_pControlEngine;
-//    qDebug() << "delete midi";
+//     qDebug() << "delete midi";
+    qDebug() << "delete midi, " << qTime.elapsed();
+    delete midi;
 //    qDebug() << "delete midiconfig";
 
     qDebug() << "delete view, " << qTime.elapsed();
@@ -444,23 +405,87 @@ MixxxApp::~MixxxApp()
     delete prefDlg;
 
     //   delete m_pBpmDetector;
-    //   delete m_pWaveSummary;
-
-    qDebug() << "save config, " << qTime.elapsed();
-    config->Save();
-    qDebug() << "delete config, " << qTime.elapsed();
-    delete config;
 
     delete frame;
-#ifdef __C_METRICS__
+
+#ifdef __C_METRICS__ // cmetrics will cause this whole method to segfault on Linux/i386 if it is called after config is deleted. Obviously, it depends on config somehow.
+	qDebug() << "cmetrics to report:" << "Mixxx deconstructor complete.";
 	cm_writemsg_ascii(MIXXXCMETRICS_MIXXX_DESTRUCTOR_COMPLETE, "Mixxx deconstructor complete.");
 	cm_close(10);
 #endif
-#ifdef __WIN__
-    _exit(0);
-#endif
+
+    qDebug() << "delete config, " << qTime.elapsed();
+    delete config;
+
+// Why is this here? The (MSVC 2008) linker even complains about it.
+//#ifdef __WINDOWS__
+//    _exit(0);
+//#endif
 }
 
+int MixxxApp::noSoundDlg(void)
+{
+    QMessageBox msgBox;
+	msgBox.setIcon(QMessageBox::Warning);
+    msgBox.setWindowTitle("Sound Device Busy");
+    msgBox.setText( "<html>Mixxx cannot access the sound device <b>"+
+                    config->getValueString(ConfigKey("[Soundcard]", "DeviceMaster"))+
+                    "</b>. "+
+                    "Another application is using the sound device or it is "+
+                    "not plugged in."+
+                    "<ul>"+
+                        "<li>"+
+                            "<b>Retry</b> after closing the other application "+
+                            "or reconnecting the sound device"+
+                        "</li>"+
+                        "<li>"+
+                            "<b>Reconfigure</b> Mixxx to use another sound device."+
+                        "</li>" +
+                        "<li>"+
+                            "Get <b>Help</b> from the Mixxx Wiki."+
+                        "</li>"+
+                        "<li>"+
+                            "<b>Exit</b> without saving your settings."+
+                        "</li>" +
+                    "</ul></html>"
+    );
+
+    QPushButton *retryButton = msgBox.addButton(tr("Retry"), QMessageBox::ActionRole);
+    QPushButton *reconfigureButton = msgBox.addButton(tr("Reconfigure"), QMessageBox::ActionRole);
+    QPushButton *wikiButton = msgBox.addButton(tr("Help"), QMessageBox::ActionRole);
+    QPushButton *exitButton = msgBox.addButton(tr("Exit"), QMessageBox::ActionRole);
+
+    while(1)
+    {
+        msgBox.exec();
+        
+        if (msgBox.clickedButton() == retryButton) {
+            soundmanager->queryDevices();
+            return 0;
+        } else if (msgBox.clickedButton() == wikiButton) {
+            QDesktopServices::openUrl(QUrl("http://mixxx.org/wiki/doku.php/troubleshooting#no_or_too_few_sound_cards_appear_in_the_preferences_dialog"));
+            wikiButton->setEnabled(false);
+        } else if (msgBox.clickedButton() == reconfigureButton) {
+            msgBox.hide();
+            soundmanager->queryDevices();
+            
+            // This way of opening the dialog allows us to use it synchronously
+            prefDlg->setWindowModality(Qt::ApplicationModal);
+            prefDlg->exec();
+            if ( prefDlg->result() == QDialog::Accepted) {
+                soundmanager->queryDevices();
+                return 0;
+            }
+            
+            msgBox.show();
+            
+        } else if (msgBox.clickedButton() == exitButton) {
+            return 1;
+        }
+    }
+}
+
+
 /** initializes all QActions of the application */
 void MixxxApp::initActions()
 {
@@ -620,7 +645,7 @@ void MixxxApp::initMenuBar()
     macroMenu=new QMenu("&Macro");
 #endif
 #ifdef __LADSPA__
-    ladspaMenu=new QMenu("LADSPA");
+//    ladspaMenu=new QMenu("LADSPA");
 #endif
 
     // menuBar entry fileMenu
@@ -666,7 +691,7 @@ void MixxxApp::initMenuBar()
     macroMenu->addAction(macroStudio);
 #endif
 #ifdef __LADSPA__
-    ladspaMenu->addAction(ladspaShow);
+    // ladspaMenu->addAction(ladspaShow);
 #endif
 
     menuBar()->addMenu(fileMenu);
@@ -678,11 +703,10 @@ void MixxxApp::initMenuBar()
     menuBar()->addMenu(macroMenu);
 #endif
 #ifdef __LADSPA__
-    menuBar()->addMenu(ladspaMenu);
+//    menuBar()->addMenu(ladspaMenu);
 #endif
     menuBar()->addSeparator();
     menuBar()->addMenu(helpMenu);
-    //new MixxxMenuPlaylists(libraryMenu, m_pTrack);
 
 }
 
@@ -734,7 +758,7 @@ void MixxxApp::slotiPodToggle(bool toggle) {
 
 //       qDebug() << "iPod file" << filePath << "--"<< fileName << "--" << fileSuffix;
 
-       TrackInfoObject* pTrack = new TrackInfoObject(filePath, fileName, m_pBpmDetector );
+       TrackInfoObject* pTrack = new TrackInfoObject(filePath, fileName);
        pTrack->setBpm(song->BPM);
        pTrack->setBpmConfirm(song->BPM != 0);  //    void setBeatFirst(float); ??
 //       pTrack->setHeaderParsed(true);
@@ -1008,77 +1032,99 @@ void MixxxApp::slotHelpAbout()
     DlgAbout *about = new DlgAbout(this);
     about->version_label->setText(VERSION);
     QString credits =
-    "<p align=\"center\"><b>Mixxx 1.6.0 Development Team</b></p>"
+    QString("<p align=\"center\"><b>Mixxx %1 Development Team</b></p>"
 "<p align=\"center\">"
 "Adam Davison<br>"
 "Albert Santoni<br>"
 "Garth Dahlstrom<br>"
-"Cedric Gestes<br>"
-"John Sully<br>"
-"Ben Wheeler<br>"
-"Micah Lee<br>"
-"Pawel Bartkiewicz<br>"
-"Nathan Prado<br>"
-"Wesley Stessens<br>"
 "RJ Ryan<br>"
+"Sean Pappalardo<br>"
+"Nick Guenther<br>"
+"Phillip Whelan<br>"
 "Zach Elko<br>"
 "Tom Care<br>"
+"Pawel Bartkiewicz<br>"
+
 "</p>"
 "<p align=\"center\"><b>With contributions from:</b></p>"
 "<p align=\"center\">"
-"Martin Sakm&#225;r<br>"
-"Ilian Persson<br>"
 "Mark Hills<br>"
-"Alex Barker<br>"
-"Dave Jarvis<br>"
-"Thomas Baag<br>"
-"Karlis Kalnins<br>"
-"Amias Channer<br>"
-"Sacha Berger<br>"
-"Stefan Langhammer<br>"
 "Andre Roth<br>"
-"Frank Willascheck<br>"
 "Robin Sheat<br>"
-"Jeff Nelson<br>"
-"Kevin Schaper<br>"
-"J&aacute;n Jockusch<br>"
-"Alex Markley<br>"
-"Oriol Puigb&oacute;<br>"
-"Ulrich Heske<br>"
-"James Hagerman<br>"
-"quil0m80<br>"
 "Michael Pujos<br>"
 "Mark Glines<br>"
+"Claudio Bantaloukas<br>"
+"Pavol Rusnak<br>"
+"Mathieu Rene<br>"
+"Miko Kiiski<br>"
+"Navaho Gunleg<br>"
+"Gavin Pryke<br>"
+"Brian Jackson<br>"
+"Owen Williams<br>"
+"James Evans<br>"
+"Martin Sakmar<br>"
+"Andreas Pflug<br>"
+"Bas van Schaik<br>"
+
 "</p>"
 "<p align=\"center\"><b>And special thanks to:</b></p>"
 "<p align=\"center\">"
+"Stanton<br>"
+"Hercules<br>"
+"Echo Digital Audio<br>"
 "Adam Bellinson<br>"
 "Melanie Thielker<br>"
 "Julien Rosener<br>"
 "Pau Arum&iacute;<br>"
 "David Garcia<br>"
 "Seb Ruiz<br>"
-"Echo Digital Audio<br>"
-"n080dy @ Free Radio <a href=\"http://freeteam.nl/patapoe/\">Patapoe</href><br>"
+"Joseph Mattiello<br>"
+"</p>"
+
+"<p align=\"center\"><b>Past Developers</b></p>"
+"<p align=\"center\">"
+"Tue Haste Andersen<br>"
+"Ken Haste Andersen<br>"
+"Cedric Gestes<br>"
+"John Sully<br>"
+"Torben Hohn<br>"
+"Peter Chang<br>"
+"Micah Lee<br>"
+"Ben Wheeler<br>"
+"Wesley Stessens<br>"
+"Nathan Prado<br>"
 "</p>"
 
 "<p align=\"center\"><b>Past Contributors</b></p>"
 "<p align=\"center\">"
-"Tue Haste Andersen<br>"
-"Ken Haste Andersen<br>"
 "Ludek Hor&#225;cek<br>"
 "Svein Magne Bang<br>"
 "Kristoffer Jensen<br>"
 "Ingo Kossyk<br>"
-"Torben Hohn<br>"
-"Peter Chang<br>"
 "Mads Holm<br>"
 "Lukas Zapletal<br>"
 "Jeremie Zimmermann<br>"
 "Gianluca Romanin<br>"
 "Tim Jackson<br>"
-"Jan Jockusch<br>"
-"</p>";
+"J&aacute;n Jockusch<br>"
+"Stefan Langhammer<br>"
+"Frank Willascheck<br>"
+"Jeff Nelson<br>"
+"Kevin Schaper<br>"
+"Alex Markley<br>"
+"Oriol Puigb&oacute;<br>"
+"Ulrich Heske<br>"
+"James Hagerman<br>"
+"quil0m80<br>"
+"Martin Sakm&#225;r<br>"
+"Ilian Persson<br>"
+"Alex Barker<br>"
+"Dave Jarvis<br>"
+"Thomas Baag<br>"
+"Karlis Kalnins<br>"
+"Amias Channer<br>"
+"Sacha Berger<br>"
+"</p>").arg(VERSION);
 
 
     about->textBrowser->setHtml(credits);
@@ -1123,7 +1169,7 @@ QString MixxxApp::getSkinPath() {
             qSkinPath.append(config->getValueString(ConfigKey("[Config]","Skin")));
         else
         {
-            config->set(ConfigKey("[Config]","Skin"), ConfigValue("outlineSmall"));
+            config->set(ConfigKey("[Config]","Skin"), ConfigValue("outlineNetbook"));
             config->Save();
             qSkinPath.append(config->getValueString(ConfigKey("[Config]","Skin")));
         }
