@@ -48,9 +48,9 @@
 // application specific includes
 #include "defs.h"
 #include "mixxxview.h"
-#include "enginebuffer.h"
-#include "enginechannel.h"
-#include "enginemaster.h"
+#include "engine/enginebuffer.h"
+#include "engine/enginechannel.h"
+#include "engine/enginemaster.h"
 #include "controlobject.h"
 #include "dlgpreferences.h"
 #include "trackplaylist.h"
@@ -70,7 +70,6 @@ class WVisual;
 class Track;
 class TrackInfoObject;
 class PlayerProxy;
-class WaveSummary;
 class BpmDetector;
 class QSplashScreen;
 class ScriptEngine;
@@ -87,7 +86,7 @@ class MixxxApp : public QMainWindow
 
   public:
     /** Construtor. files is a list of command line arguments */
-    MixxxApp(QApplication *app, struct CmdlineArgs args, QSplashScreen *pSplash);
+    MixxxApp(QApplication *app, struct CmdlineArgs args);
     /** destructor */
     ~MixxxApp();
     /** initializes all QActions of the application */
@@ -146,11 +145,6 @@ class MixxxApp : public QMainWindow
      * changing the view class.
      */
     MixxxView *view;
-    /** Pointer to waveform summary generator */
-    WaveSummary *m_pWaveSummary;
-    /** Pointer to the bpm detector */
-    BpmDetector *m_pBpmDetector;
-
     QFrame *frame;
 
     QApplication *app;
@@ -163,8 +157,6 @@ class MixxxApp : public QMainWindow
     MidiObject *midi;
     ControlObject *control;
     ConfigObject<ConfigValue> *config;
-    /** Pointer to active midi configuration */
-    ConfigObject<ConfigValueMidi> *midiconfig;
     /** Pointer to active keyboard configuration */
     ConfigObject<ConfigValueKbd> *kbdconfig;
     /** Pointer to track object */
@@ -244,6 +236,7 @@ class MixxxApp : public QMainWindow
     DlgLADSPA *ladspaDlg;
 #endif
 
+    int noSoundDlg(void);
     // Fullscreen patch
     QPoint winpos;
 };
@@ -252,9 +245,8 @@ class MixxxApp : public QMainWindow
 struct CmdlineArgs
 {
     QList<QString> qlMusicFiles;    /* List of files to load into players at startup */
-    QString qLogFileName;           /* Log file */ 
     bool bStartInFullscreen;        /* Start in fullscreen mode */
 };
 
-#endif
 
+#endif
