@@ -16,58 +16,48 @@
 *                                                                         *
 ***************************************************************************/
 
+#include <QtCore>
+#include <QtGui>
+
 #include "mixxxview.h"
-
-#include <QDir>
-#include <QPixmap>
-#include <QToolTip>
-#include <QEvent>
-#include <QMenuBar>
-#include <QList>
-#include <QTableView>
-#include <QLabel>
-#include <QComboBox>
-//#include <QLineEdit>
-#include <QMainWindow>
-#include <QPushButton>
-#include <QTableView>
-#include <QLineEdit>
-#include <QtDebug>
-#include <QMessageBox>
-
 #include "wtracktablemodel.h"
 #include "wtracktableview.h"
-#include "wwidget.h"
-#include "wabstractcontrol.h"
-#include "wknob.h"
-#include "wpushbutton.h"
-#include "wslider.h"
-#include "wslidercomposed.h"
-#include "wdisplay.h"
-#include "wvumeter.h"
-#include "wstatuslight.h"
-#include "wlabel.h"
-#include "wnumber.h"
-#include "wnumberpos.h"
-#include "wnumberbpm.h"
-#include "wnumberrate.h"
-#include "wpixmapstore.h"
-#include "wsearchlineedit.h"
+#include "widget/wwidget.h"
+#include "widget/wabstractcontrol.h"
+#include "widget/wknob.h"
+#include "widget/wpushbutton.h"
+#include "widget/wslider.h"
+#include "widget/wslidercomposed.h"
+#include "widget/wdisplay.h"
+#include "widget/wvumeter.h"
+#include "widget/wstatuslight.h"
+#include "widget/wlabel.h"
+#include "widget/wnumber.h"
+#include "widget/wnumberpos.h"
+#include "widget/wnumberbpm.h"
+#include "widget/wnumberrate.h"
+#include "widget/wpixmapstore.h"
+#include "widget/wsearchlineedit.h"
 
-#include "woverview.h"
+#include "widget/woverview.h"
 #include "mixxxkeyboard.h"
 #include "controlobject.h"
 #include "controlobjectthreadwidget.h"
 #include "waveformviewerfactory.h"
-#include "wvisualsimple.h"
-#include "wglwaveformviewer.h"
-#include "wwaveformviewer.h"
+#include "waveform/waveformrenderer.h"
+#include "widget/wvisualsimple.h"
+#include "widget/wglwaveformviewer.h"
+#include "widget/wwaveformviewer.h"
 
 #include "imgloader.h"
 #include "imginvert.h"
 #include "imgcolor.h"
-#include "wskincolor.h"
+#include "widget/wskincolor.h"
 #include "mixxx.h"
+#ifdef __LADSPA__
+#include "dlgladspa.h"
+#include "ladspaview.h"
+#endif
 #include "defs_promo.h"
 
 MixxxView::MixxxView(QWidget * parent, ConfigObject<ConfigValueKbd> * kbdconfig, QString qSkinPath, ConfigObject<ConfigValue> * pConfig) : QWidget(parent)
@@ -82,13 +72,16 @@ MixxxView::MixxxView(QWidget * parent, ConfigObject<ConfigValueKbd> * kbdconfig,
     // Try to open the file pointed to by qSkinPath
     QDomElement docElem = openSkin(qSkinPath);
 
-#ifdef __WIN__
+#ifdef __WINDOWS__
 #ifndef QT3_SUPPORT
     // QPixmap fix needed on Windows 9x
     QPixmap::setDefaultOptimization(QPixmap::MemoryOptim);
 #endif
 #endif
 
+    m_pWaveformRendererCh1 = new WaveformRenderer("[Channel1]");
+    m_pWaveformRendererCh2 = new WaveformRenderer("[Channel2]");
+    
     // Default values for visuals
     //m_pTrackTable = 0;
     m_pTextCh1 = 0;
@@ -105,13 +98,18 @@ MixxxView::MixxxView(QWidget * parent, ConfigObject<ConfigValueKbd> * kbdconfig,
     m_pComboBox = 0;
     m_pTrackTableView = 0;
     m_pLineEditSearch = 0;
+    m_pTabWidget = 0;
+    m_pTabWidgetLibraryPage = 0;
+    m_pTabWidgetEffectsPage = 0;
+    m_pLibraryPageLayout = new QGridLayout();
+    m_pEffectsPageLayout = new QGridLayout();
 
     setupColorScheme(docElem, pConfig);
 
     // Load all widgets defined in the XML file
     createAllWidgets(docElem, parent, pConfig);
 
-#ifdef __WIN__
+#ifdef __WINDOWS__
 #ifndef QT3_SUPPORT
     // QPixmap fix needed on Windows 9x
     QPixmap::setDefaultOptimization(QPixmap::NormalOptim);
@@ -123,6 +121,28 @@ MixxxView::MixxxView(QWidget * parent, ConfigObject<ConfigValueKbd> * kbdconfig,
 MixxxView::~MixxxView()
 {
     //m_qWidgetList.clear();
+
+    if(m_pVisualCh1) {
+	m_qWidgetList.remove(m_pVisualCh1);
+	delete m_pVisualCh1;
+	m_pVisualCh1 = NULL;
+    }
+    
+    if(m_pVisualCh2) {
+	m_qWidgetList.remove(m_pVisualCh2);
+	delete m_pVisualCh2;
+	m_pVisualCh2 = NULL;
+    }
+
+    if(m_pWaveformRendererCh1) {
+	delete m_pWaveformRendererCh1;
+	m_pWaveformRendererCh1 = NULL;
+    }
+    
+    if(m_pWaveformRendererCh2) {
+	delete m_pWaveformRendererCh2;
+	m_pWaveformRendererCh2 = NULL;
+    }
 }
 
 void MixxxView::checkDirectRendering()
@@ -248,14 +268,15 @@ QDomElement MixxxView::openSkin(QString qSkinPath) {
     QDomDocument skin("skin");
     QFile file(WWidget::getPath("skin.xml"));
     QFileInfo fi(file);
-
+    QByteArray qbaFilename = fi.fileName().toUtf8();
+    
     if (!file.open(QIODevice::ReadOnly))
-    {
-	qFatal("Could not open skin definition file: %s", (char *)fi.fileName().constData());
+    {  
+        qFatal("Could not open skin definition file: %s", qbaFilename.constData());
     }
     if (!skin.setContent(&file))
     {
-	qFatal("Error parsing skin definition file: %s", (char *)fi.fileName().constData());
+        qFatal("Error parsing skin definition file: %s", qbaFilename.constData());
     }
 
     file.close();
@@ -443,12 +464,68 @@ void MixxxView::createAllWidgets(QDomElement docElem,
                 p->setup(node);
                 p->installEventFilter(m_pKeyboard);
             }
+            else if (node.nodeName()=="Visual")
+            {
+		WaveformViewerType type;
+		
+                if (WWidget::selectNodeInt(node, "Channel")==1)
+                {
+		    type = WaveformViewerFactory::createWaveformViewer("[Channel1]", this, pConfig, &m_pVisualCh1, m_pWaveformRendererCh1);
+		    m_qWidgetList.append(m_pVisualCh1);
 
+		    m_pVisualCh1->installEventFilter(m_pKeyboard);
 
+		    // Hook up [Channel1],wheel Control Object to the Visual Controller
+		    ControlObjectThreadWidget * p = new ControlObjectThreadWidget(ControlObject::getControl(ConfigKey("[Channel1]", "wheel")));
+		    p->setWidget((QWidget *)m_pVisualCh1, true, Qt::LeftButton);
+			
+		    //ControlObject::setWidget((QWidget *)m_pVisualCh1, ConfigKey("[Channel1]", "wheel"), true, Qt::LeftButton);
+ 
+		    // Things to do whether the waveform was previously created or not
+		    if(type == WAVEFORM_GL) {
+			m_bVisualWaveform = true; // TODO : remove this crust
+			((WGLWaveformViewer*)m_pVisualCh1)->setup(node);
+			// TODO rryan re-enable this later
+			/*
+			((WVisualWaveform*)m_pVisualCh1)->resetColors();
+			*/
+		    } else if (type == WAVEFORM_WIDGET) {
+			m_bVisualWaveform = true;
+			((WWaveformViewer *)m_pVisualCh1)->setup(node);
+		    } else if (type == WAVEFORM_SIMPLE) {
+			((WVisualSimple*)m_pVisualCh1)->setup(node);
+		    }
+		}
+		else if (WWidget::selectNodeInt(node, "Channel")==2)
+		{
+		    type = WaveformViewerFactory::createWaveformViewer("[Channel2]", this, pConfig, &m_pVisualCh2, m_pWaveformRendererCh2);
+		    m_qWidgetList.append(m_pVisualCh2);
+			
+		    m_pVisualCh2->installEventFilter(m_pKeyboard);
+			
+		    // Hook up [Channel1],wheel Control Object to the Visual Controller
+		    ControlObjectThreadWidget * p = new ControlObjectThreadWidget(ControlObject::getControl(ConfigKey("[Channel2]", "wheel")));
+		    p->setWidget((QWidget *)m_pVisualCh2, true, Qt::LeftButton);
 
-
-
-
+		    //ControlObject::setWidget((QWidget *)m_pVisualCh2, ConfigKey("[Channel2]", "wheel"), true, Qt::LeftButton);
+		    
+		    // Things to do whether the waveform was previously created or not
+		    if(type == WAVEFORM_GL) {
+			m_bVisualWaveform = true; // TODO : remove this crust
+			
+			((WGLWaveformViewer*)m_pVisualCh2)->setup(node);
+			// TODO rryan re-enable this later
+			/*
+			((WVisualWaveform*)m_pVisualCh2)->resetColors();
+			*/
+		    } else if (type == WAVEFORM_WIDGET) {
+			m_bVisualWaveform = true;
+			((WWaveformViewer *)m_pVisualCh2)->setup(node);
+		    } else if (type == WAVEFORM_SIMPLE) {
+			((WVisualSimple*)m_pVisualCh2)->setup(node);
+		    }
+		}
+            }
 
             /*############## PERSISTENT OBJECT ##############*/
             // persistent: m_pTextCh1, m_pTextCh2
@@ -515,81 +592,7 @@ void MixxxView::createAllWidgets(QDomElement docElem,
 
 
 
-            // persistent: m_pVisualCh1, m_pVisualCh2
-            else if (node.nodeName()=="Visual")
-            {
-		WaveformViewerType type;
-		
-                if (WWidget::selectNodeInt(node, "Channel")==1)
-                {
-		    if(m_pVisualCh1 == NULL) {
-			type = WaveformViewerFactory::createWaveformViewer("[Channel1]", this, pConfig, &m_pVisualCh1);
 
-			m_pVisualCh1->installEventFilter(m_pKeyboard);
-
-			// Hook up [Channel1],wheel Control Object to the Visual Controller
-			ControlObjectThreadWidget * p = new ControlObjectThreadWidget(ControlObject::getControl(ConfigKey("[Channel1]", "wheel")));
-			p->setWidget((QWidget *)m_pVisualCh1, true, Qt::LeftButton);
-			
-			//ControlObject::setWidget((QWidget *)m_pVisualCh1, ConfigKey("[Channel1]", "wheel"), true, Qt::LeftButton);
-		    } else {
-			type = WaveformViewerFactory::getWaveformViewerType(m_pVisualCh1);
-		    }
-
-		    // Things to do whether the waveform was previously created or not
-		    if(type == WAVEFORM_GL) {
-			m_bVisualWaveform = true; // TODO : remove this crust
-			((WGLWaveformViewer*)m_pVisualCh1)->setup(node);
-			// TODO rryan re-enable this later
-			/*
-			((WVisualWaveform*)m_pVisualCh1)->resetColors();
-			*/
-		    } else if (type == WAVEFORM_WIDGET) {
-			m_bVisualWaveform = true;
-			((WWaveformViewer *)m_pVisualCh1)->setup(node);
-		    } else if (type == WAVEFORM_SIMPLE) {
-			((WVisualSimple*)m_pVisualCh1)->setup(node);
-		    }
-		    ((QWidget*)m_pVisualCh1)->show();
-		    ((QWidget*)m_pVisualCh1)->repaint();
-		    
-		}
-		else if (WWidget::selectNodeInt(node, "Channel")==2)
-		{
-		    if(m_pVisualCh2 == NULL) {
-			type = WaveformViewerFactory::createWaveformViewer("[Channel2]", this, pConfig, &m_pVisualCh2);
-			
-			m_pVisualCh2->installEventFilter(m_pKeyboard);
-			
-			// Hook up [Channel1],wheel Control Object to the Visual Controller
-			ControlObjectThreadWidget * p = new ControlObjectThreadWidget(ControlObject::getControl(ConfigKey("[Channel2]", "wheel")));
-			p->setWidget((QWidget *)m_pVisualCh2, true, Qt::LeftButton);
-
-			//ControlObject::setWidget((QWidget *)m_pVisualCh2, ConfigKey("[Channel2]", "wheel"), true, Qt::LeftButton);
-		    }  else {
-			type = WaveformViewerFactory::getWaveformViewerType(m_pVisualCh2);
-		    }
-		    
-		    // Things to do whether the waveform was previously created or not
-		    if(type == WAVEFORM_GL) {
-			m_bVisualWaveform = true; // TODO : remove this crust
-			
-			((WGLWaveformViewer*)m_pVisualCh2)->setup(node);
-			// TODO rryan re-enable this later
-			/*
-			((WVisualWaveform*)m_pVisualCh2)->resetColors();
-			*/
-		    } else if (type == WAVEFORM_WIDGET) {
-			m_bVisualWaveform = true;
-			((WWaveformViewer *)m_pVisualCh2)->setup(node);
-		    } else if (type == WAVEFORM_SIMPLE) {
-			((WVisualSimple*)m_pVisualCh2)->setup(node);
-		    }
-		    ((QWidget*)m_pVisualCh2)->show();
-		    ((QWidget*)m_pVisualCh2)->repaint();
-		}
-		
-            }
 
 
 
@@ -685,17 +688,22 @@ void MixxxView::createAllWidgets(QDomElement docElem,
                         m_pComboBox->addItem( "Free Tracks", TABLE_MODE_PROMO );
                     // m_pComboBox->addItem( "iPod", TABLE_MODE_IPOD );
                     m_pComboBox->installEventFilter(m_pKeyboard);
+               
+                    //Add the combo box to the the library page's layout.
+                    m_pLibraryPageLayout->addWidget(m_pComboBox, 0, 0, Qt::AlignLeft); //Row 0, col 0
                 }
+                /*
                 // Set position
                 QString pos = WWidget::selectNodeQString(node, "Pos");
                 int x = pos.left(pos.indexOf(",")).toInt();
                 int y = pos.mid(pos.indexOf(",")+1).toInt();
                 m_pComboBox->move(x,y);
+                */
 
                 // Size
                 QString size = WWidget::selectNodeQString(node, "Size");
-                x = size.left(size.indexOf(",")).toInt();
-                y = size.mid(size.indexOf(",")+1).toInt();
+                int x = size.left(size.indexOf(",")).toInt();
+                int y = size.mid(size.indexOf(",")+1).toInt();
                 m_pComboBox->setFixedSize(x,y);
                 m_pComboBox->show();
             }
@@ -706,19 +714,22 @@ void MixxxView::createAllWidgets(QDomElement docElem,
                 if (m_pLineEditSearch == 0) {
 					MixxxView* parent = this;
                     QString path = pConfig->getConfigPath();
-                    m_pLineEditSearch = new WSearchLineEdit(path, (QWidget*)parent);
+                    m_pLineEditSearch = new WSearchLineEdit(path, this);
+                    m_pLibraryPageLayout->addWidget(m_pLineEditSearch, 0, 2, Qt::AlignRight); //Row 0, col 2
                 }
-
+                
+                /*
                 // Set position
                 QString pos = WWidget::selectNodeQString(node, "Pos");
                 int x = pos.left(pos.indexOf(",")).toInt();
                 int y = pos.mid(pos.indexOf(",")+1).toInt();
                 m_pLineEditSearch->move(x+35,y);
+                */
 
                 // Size
                 QString size = WWidget::selectNodeQString(node, "Size");
-                x = size.left(size.indexOf(",")).toInt();
-                y = size.mid(size.indexOf(",")+1).toInt();
+                int x = size.left(size.indexOf(",")).toInt();
+                int y = size.mid(size.indexOf(",")+1).toInt();
                 m_pLineEditSearch->setFixedSize(x,y);
                 m_pLineEditSearch->show();
             }
@@ -726,9 +737,55 @@ void MixxxView::createAllWidgets(QDomElement docElem,
 	    // persistent: m_pTrackTableView
             else if (node.nodeName()=="TableView")
             {
+                if (m_pTabWidget == 0) {
+
+                    //Create the tab widget to store the various panes in (library, effects, etc.)
+                    m_pTabWidget = new QStackedWidget(this);
+
+                    //Create the pages that go in the tab widget
+                    m_pTabWidgetLibraryPage = new QWidget();
+                    m_pTabWidgetLibraryPage = new QWidget(this);
+                    //m_pTabWidgetEffectsPage = new QWidget();
+                    //m_pDlgLADSPA = new DlgLADSPA(this);
+
+                    m_pLADSPAView = new LADSPAView(this);
+                    m_pTabWidgetEffectsPage = m_pLADSPAView; //m_pDlgLADSPA; 
+                    //Set the margins to be 0 for all the layouts.
+                    m_pLibraryPageLayout->setContentsMargins(0, 0, 0, 0);
+      //              m_pEffectsPageLayout->setContentsMargins(0, 0, 0, 0);
+
+                    m_pTabWidgetLibraryPage->setLayout(m_pLibraryPageLayout);
+    //                m_pTabWidgetEffectsPage->setLayout(m_pEffectsPageLayout);
+                }
+
                 if (m_pTrackTableView == 0) {
                     m_pTrackTableView = new WTrackTableView(this, pConfig);
+                    //Add the track table to the library page's layout, so it's positioned/sized automatically
+                    m_pLibraryPageLayout->addWidget(m_pTrackTableView,
+                                                    1, 0, //From row 1, col 0,
+                                                    1,    //Span 1 row
+                                                    3,    //Span 3 cols
+                                                    0);   //Default alignment
+
+                    //Add the library page to the tab widget.
+                    m_pTabWidget->addWidget(m_pTabWidgetLibraryPage);//, tr("Library"));
+                    
+                    //Add the effects page to the tab widget.
+                    m_pTabWidget->addWidget(m_pTabWidgetEffectsPage);//, tr("Effects"));      
+                    
+                    /*
+                    //XXX: Re-enable this to get the tab widget back, post 1.7.0 release.
+                    //Add the library page to the tab widget.
+                    m_pTabWidget->addWidget(m_pTabWidgetLibraryPage, tr("Library"));
+                    
+                    //Add the effects page to the tab widget.
+                    m_pTabWidget->addWidget(m_pTabWidgetEffectsPage, tr("Effects"));   
+		    */             
                 }
+                
+                //Move the tab widget into position and size it properly.
+                setupTabWidget(node);
+
                 m_pTrackTableView->setup(node);
                 m_pTrackTableView->installEventFilter(m_pKeyboard);
                 m_pTrackTableView->show();
@@ -758,6 +815,11 @@ void MixxxView::rebootGUI(QWidget * parent, ConfigObject<ConfigValue> * pConfig,
 
     // This isn't thread safe, does anything else hack on this object?
 
+    // Temporary hack since we keep these pointers around, but we have them on
+    // the widget list.
+    m_pVisualCh1 = NULL;
+    m_pVisualCh2 = NULL;
+    
     //remove all widget from the list (except permanent one)
     while (!m_qWidgetList.isEmpty()) {
         delete m_qWidgetList.takeFirst();
@@ -766,8 +828,6 @@ void MixxxView::rebootGUI(QWidget * parent, ConfigObject<ConfigValue> * pConfig,
     //hide permanent widget
     if (m_pTextCh1) m_pTextCh1->hide();
     if (m_pTextCh2) m_pTextCh2->hide();
-    if (m_pVisualCh1) ((QWidget *)m_pVisualCh1)->hide();
-    if (m_pVisualCh2) ((QWidget *)m_pVisualCh2)->hide();
     if (m_pNumberPosCh1) m_pNumberPosCh1->hide();
     if (m_pNumberPosCh2) m_pNumberPosCh2->hide();
     if (m_pSliderRateCh1) m_pSliderRateCh1->hide();
@@ -788,8 +848,6 @@ void MixxxView::rebootGUI(QWidget * parent, ConfigObject<ConfigValue> * pConfig,
         obj = m_qWidgetList[i];
         ((QWidget *)obj)->show();
     }
-    if (m_pVisualCh1) ((QWidget *)m_pVisualCh1)->repaint();
-    if (m_pVisualCh2) ((QWidget *)m_pVisualCh2)->repaint();
 }
 
 
@@ -812,3 +870,23 @@ QList<QString> MixxxView::getSchemeList(QString qSkinPath) {
     return schlist;
 }
 
+void MixxxView::setupTabWidget(QDomNode node)
+{
+    // Position
+    if (!WWidget::selectNode(node, "Pos").isNull())
+    {
+        QString pos = WWidget::selectNodeQString(node, "Pos");
+        int x = pos.left(pos.indexOf(",")).toInt();
+        int y = pos.mid(pos.indexOf(",")+1).toInt();
+        m_pTabWidget->move(x,y);
+    }
+
+    // Size
+    if (!WWidget::selectNode(node, "Size").isNull())
+    {
+        QString size = WWidget::selectNodeQString(node, "Size");
+        int x = size.left(size.indexOf(",")).toInt();
+        int y = size.mid(size.indexOf(",")+1).toInt();
+        m_pTabWidget->setFixedSize(x,y);
+    }
+ }
