@@ -46,7 +46,13 @@ class MixxxKeyboard;
 class QComboBox;
 class QLineEdit;
 class QPushButton;
+class QGridLayout;
+class QTabWidget;
+class QStackedWidget;
 class WTrackTableView;
+class DlgLADSPA; class LADSPAView;
+class WaveformRenderer;
+
 /**
  * This class provides an incomplete base for your application view.
  */
@@ -70,6 +76,7 @@ public:
     QLabel *m_pTextCh1, *m_pTextCh2;
     /** Pointer to WVisual widgets */
     QObject *m_pVisualCh1, *m_pVisualCh2;
+    WaveformRenderer *m_pWaveformRendererCh1, *m_pWaveformRendererCh2;
     /** Pointer to absolute file position widgets */
     WNumberPos *m_pNumberPosCh1, *m_pNumberPosCh2;
     /** Pointer to rate slider widgets */
@@ -92,6 +99,7 @@ public:
 private:
     void setupColorScheme(QDomElement docElem, ConfigObject<ConfigValue> *pConfig);
     void createAllWidgets(QDomElement docElem, QWidget* parent, ConfigObject<ConfigValue> *pConfig);
+    void setupTabWidget(QDomNode node);
 
     /*temp to change view*/
     WTrackTable *m_pTmpPlaylist;
@@ -108,6 +116,22 @@ private:
     /** Pointer to keyboard handler */
     MixxxKeyboard *m_pKeyboard;
     ConfigObject<ConfigValue> *m_pconfig;
+
+    /** Tab widget, which contains several "pages" for different views */
+    QStackedWidget* m_pTabWidget; //XXX: Temporarily turned this into a QStackedWidget instead of a QTabWidget to disable the tabs for 1.7.0 since LADSPA effects isn't finished.
+    /** The widget containing the library/tracktable page */
+    QWidget* m_pTabWidgetLibraryPage;
+    /** The widget containing the effects/LADSPA page */
+    QWidget* m_pTabWidgetEffectsPage;
+    /** The layout for the library page. Allows stuff to resize automatically */
+    QGridLayout* m_pLibraryPageLayout;
+    /** The layout for the effects page. Allows stuff to resize automatically */
+    QGridLayout* m_pEffectsPageLayout;
+
+#ifdef __LADSPA__
+    DlgLADSPA* m_pDlgLADSPA;
+    LADSPAView* m_pLADSPAView;
+#endif
 };
 
 #endif
