@@ -10,10 +10,12 @@
 //
 //
 
-#ifdef __WIN__
+#ifdef __WINDOWS__
 #include <windows.h> // for Sleep()  on Windows
 #endif
 
+#include "defs_version.h"
+
 #include "track.h"
 #include "trackinfoobject.h"
 #include "trackcollection.h"
@@ -42,19 +44,17 @@
 
 //#include "wtreeview.h"
 #include "dlgbpmtap.h"
-#include "wnumberpos.h"
+#include "widget/wnumberpos.h"
 #include <QMenu>
 #include <QCursor>
 #include <q3cstring.h>
-#include "enginebuffer.h"
+#include "engine/enginebuffer.h"
 #include "reader.h"
 #include "controlobject.h"
 #include "controlobjectthreadmain.h"
 #include "configobject.h"
+#include "analyserqueue.h"
 #include "trackimporter.h"
-#include "wavesummary.h"
-#include "bpmdetector.h"
-#include "woverview.h"
 #include "playerinfo.h"
 #include "defs_promo.h"
 #include "soundsourceproxy.h"
@@ -67,18 +67,20 @@
 #include <QDebug>
 
 // Include widget object types for eventFilter
-#include "wslidercomposed.h"
-#include "wknob.h"
-#include "woverview.h"
-//#include "wpushButton.h"
-#include "wwidget.h"
+#include "widget/wslidercomposed.h"
+#include "widget/wknob.h"
+#include "widget/woverview.h"
+//#include "widget/wpushButton.h"
+#include "widget/wwidget.h"
 
 #ifdef __C_METRICS__
 #include <cmetrics.h>
 #include "defs_mixxxcmetrics.h"
 #endif
 
-Track::Track(QString location, MixxxView * pView, ConfigObject<ConfigValue> *config, EngineBuffer * pBuffer1, EngineBuffer * pBuffer2, WaveSummary * pWaveSummary, BpmDetector * pBpmDetector)
+Track::Track(QString location, MixxxView * pView, ConfigObject<ConfigValue> *config, 
+             EngineBuffer * pBuffer1, EngineBuffer * pBuffer2,
+             AnalyserQueue* analyserQueue)
 {
     m_pView = pView;
     m_pBuffer1 = pBuffer1;
@@ -87,13 +89,13 @@ Track::Track(QString location, MixxxView * pView, ConfigObject<ConfigValue> *con
     m_pActivePopupPlaylist = 0;
     m_pTrackPlayer1 = 0;
     m_pTrackPlayer2 = 0;
-    m_pWaveSummary = pWaveSummary;
-    m_pBpmDetector = pBpmDetector;
     m_pConfig = config;
     m_iLibraryIdx = 0;   //FIXME: Deprecated, can safely remove.
     m_iPlayqueueIdx = 0; //FIXME: Deprecated, can safely remove.
 
-    m_pTrackCollection = new TrackCollection(m_pBpmDetector);
+    m_analyserQueue = analyserQueue;
+
+    m_pTrackCollection = new TrackCollection();
     m_pTrackImporter = new TrackImporter(m_pView,m_pTrackCollection);
     m_pLibraryModel = new WTrackTableModel(m_pView->m_pTrackTableView);
     m_pPlayQueueModel = new WTrackTableModel(m_pView->m_pTrackTableView);
@@ -109,6 +111,8 @@ Track::Track(QString location, MixxxView * pView, ConfigObject<ConfigValue> *con
     m_qPlayqueuePlaylist.setTrackCollection(m_pTrackCollection);
     m_qPromoPlaylist.setTrackCollection(m_pTrackCollection);
 
+    m_timerID = 0;
+
 #ifdef __IPOD__
     m_qIPodPlaylist.setTrackCollection(m_pTrackCollection);
     m_qIPodPlaylist.setListName(PLAYLIST_NAME_IPOD);
@@ -161,7 +165,8 @@ Track::Track(QString location, MixxxView * pView, ConfigObject<ConfigValue> *con
         qDebug() << "Trying to add" << m_pTrackCollection->getSize() << "songs to the library playlist";
         for (int i = 0; i < m_pTrackCollection->getSize(); i++)
         {
-            m_qLibraryPlaylist.addTrack(m_pTrackCollection->getTrack(i));
+            TrackInfoObject* track = m_pTrackCollection->getTrack(i);
+            if (track != NULL) m_qLibraryPlaylist.addTrack(track);
         }
 
         m_pView->m_pTrackTableView->setSearchSource(m_pLibraryModel);
@@ -178,16 +183,16 @@ Track::Track(QString location, MixxxView * pView, ConfigObject<ConfigValue> *con
 /*
         connect( m_pView->m_pLineEditSearch,
                 SIGNAL( textChanged( const QString & )),
-		m_pView->m_pTrackTableView,
-		SLOT(slotFilter(const QString &)));
+        m_pView->m_pTrackTableView,
+        SLOT(slotFilter(const QString &)));
 */
 
         savedRowPosition = 0;
-        startTimer(250);   // Update the TrackTableView filter a maximum of 4 times a second.
+        m_timerID = startTimer(250);   // Update the TrackTableView filter a maximum of 4 times a second.
 
-	// add EventFilter to do a selectAll text when the LineEditSearch gains focus
-	m_pView->m_pLineEditSearch-> installEventFilter(this);
-	m_pView->installEventFilter(this);
+    // add EventFilter to do a selectAll text when the LineEditSearch gains focus
+    m_pView->m_pLineEditSearch-> installEventFilter(this);
+    m_pView->installEventFilter(this);
 
         // Connect drop events to table
         //connect(m_pView->m_pTrackTable, SIGNAL(dropped(QDropEvent *)), this, SLOT(slotDrop(QDropEvent *)));
@@ -196,9 +201,9 @@ Track::Track(QString location, MixxxView * pView, ConfigObject<ConfigValue> *con
     {
         //If there was no TrackTableView specified in the skin, give a warning.
         QMessageBox::warning(NULL, tr("Mixxx"),
-                             tr("You're using a skin that is incompatible with Mixxx " + QString(VERSION) + ", which "
+                             QString(tr("You're using a skin that is incompatible with Mixxx %1, which "
                              "will cause unexpected behaviour (eg. missing library).\nThis can happen if you're "
-                             "using a third-party skin or if you've incorrectly upgraded Mixxx."),
+                             "using a third-party skin or if you've incorrectly upgraded Mixxx.")).arg(VERSION),
                              QMessageBox::Ok, QMessageBox::Ok);
 
     }
@@ -218,6 +223,11 @@ Track::Track(QString location, MixxxView * pView, ConfigObject<ConfigValue> *con
     m_pPlayButtonCh1 = new ControlObjectThreadMain(ControlObject::getControl(ConfigKey("[Channel1]","play")));
     m_pPlayButtonCh2 = new ControlObjectThreadMain(ControlObject::getControl(ConfigKey("[Channel2]","play")));
 
+    // Get cue points 
+    m_pCuePointCh1 = new ControlObjectThreadMain(ControlObject::getControl(ConfigKey("[Channel1]","cue_point")));
+    m_pCuePointCh2 = new ControlObjectThreadMain(ControlObject::getControl(ConfigKey("[Channel2]","cue_point")));
+
+
     // Play position for each player. Used to determine which track to load next
     m_pPlayPositionCh1 = new ControlObjectThreadMain(ControlObject::getControl(ConfigKey("[Channel1]","playposition")));
     m_pPlayPositionCh2 = new ControlObjectThreadMain(ControlObject::getControl(ConfigKey("[Channel2]","playposition")));
@@ -258,7 +268,11 @@ Track::Track(QString location, MixxxView * pView, ConfigObject<ConfigValue> *con
 
     TrackPlaylist::setTrack(this);
 
-	m_pView->m_pTrackTableView->repaintEverything();
+
+    connect(m_pBuffer1->getReader(), SIGNAL(finishedLoading(TrackInfoObject*, bool)), this, SLOT(slotFinishLoadingPlayer1(TrackInfoObject*, bool)));
+    connect(m_pBuffer2->getReader(), SIGNAL(finishedLoading(TrackInfoObject*, bool)), this, SLOT(slotFinishLoadingPlayer2(TrackInfoObject*, bool)));
+
+    m_pView->m_pTrackTableView->repaintEverything();
 
 }
 
@@ -266,30 +280,37 @@ Track::~Track()
 {
 }
 
+void Track::appShuttingDown() {
+    
+    if (m_timerID != 0) {
+        killTimer(m_timerID);
+    }
+}
+
 void Track::resizeColumnsForLibraryMode()
 {
         double centa = m_pView->m_pTrackTableView->size().width()/100.;
         qDebug() << "Adjusting column widths: tracktable width =" << m_pView->m_pTrackTableView->size().width() <<" 1% of that is:"<< centa << " FIXME: this should be done when initalizing the skin.";
         m_pView->m_pTrackTableView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-        m_pView->m_pTrackTableView->setColumnWidth(COL_ARTIST, 15 * centa);
-        m_pView->m_pTrackTableView->setColumnWidth(COL_TITLE, 40 * centa);
-        m_pView->m_pTrackTableView->setColumnWidth(COL_TYPE, (20/4.) * centa);
-        m_pView->m_pTrackTableView->setColumnWidth(COL_LENGTH, (20/4.) * centa);
-        m_pView->m_pTrackTableView->setColumnWidth(COL_BITRATE, (20/4.) * centa);
-        m_pView->m_pTrackTableView->setColumnWidth(COL_BPM, (20/4.) * centa);
-        m_pView->m_pTrackTableView->setColumnWidth(COL_COMMENT, 25 * centa);
+        m_pView->m_pTrackTableView->setColumnWidth(WTrackTableModel::ARTIST, 15 * centa);
+        m_pView->m_pTrackTableView->setColumnWidth(WTrackTableModel::TITLE, 40 * centa);
+        m_pView->m_pTrackTableView->setColumnWidth(WTrackTableModel::TYPE, (20/4.) * centa);
+        m_pView->m_pTrackTableView->setColumnWidth(WTrackTableModel::LENGTH, (20/4.) * centa);
+        m_pView->m_pTrackTableView->setColumnWidth(WTrackTableModel::BITRATE, (20/4.) * centa);
+        m_pView->m_pTrackTableView->setColumnWidth(WTrackTableModel::BPM, (20/4.) * centa);
+        m_pView->m_pTrackTableView->setColumnWidth(WTrackTableModel::COMMENT, 25 * centa);
         if ( (20/4.) * centa <= 42 ) { // If we won't get enough percentage to display length, we have to make some adjustments...
           qDebug() << "Shrinking Title/Comment for small screen... ";
-          m_pView->m_pTrackTableView->setColumnWidth(COL_TYPE, 35);
-          m_pView->m_pTrackTableView->setColumnWidth(COL_LENGTH, 42);
-          m_pView->m_pTrackTableView->setColumnWidth(COL_BITRATE, 33);
-          m_pView->m_pTrackTableView->setColumnWidth(COL_BPM, 40);
-          m_pView->m_pTrackTableView->setColumnWidth(COL_TITLE, (60 * centa) - (35+42+33+40));
+          m_pView->m_pTrackTableView->setColumnWidth(WTrackTableModel::TYPE, 35);
+          m_pView->m_pTrackTableView->setColumnWidth(WTrackTableModel::LENGTH, 42);
+          m_pView->m_pTrackTableView->setColumnWidth(WTrackTableModel::BITRATE, 33);
+          m_pView->m_pTrackTableView->setColumnWidth(WTrackTableModel::BPM, 40);
+          m_pView->m_pTrackTableView->setColumnWidth(WTrackTableModel::TITLE, (60 * centa) - (35+42+33+40));
         }
 }
 
 void Track::timerEvent(QTimerEvent *event) {
-  if (m_pView && m_pView->m_pTrackTableView && m_pView->m_pLineEditSearch->isModified()) {
+  if (m_pView && m_pView->m_pTrackTableView && m_pView->m_pLineEditSearch && m_pView->m_pLineEditSearch->isModified()) {
 
       if (m_pView->m_pTrackTableView->getTableMode() == TABLE_MODE_LIBRARY && m_pView->m_pLineEditSearch->text() == "") {
       // qDebug() << "Restore viewport to position to row:" << savedRowPosition;
@@ -379,30 +400,30 @@ void Track::initPromoTracks()
  */
 void Track::loadPromoTrackXMLData(QString xmlPath, QString promoDirPath)
 {
-	//Load settings, and set defaults for anything that we failed to find
-	QDomDocument doc("promotracks");
-	QFile file(xmlPath);
-	if (!file.open(QIODevice::ReadOnly))
-	{
-		return;
-	}
-	if (!doc.setContent(&file)) {
-		file.close();
-		return;
-	}
-	file.close();
+    //Load settings, and set defaults for anything that we failed to find
+    QDomDocument doc("promotracks");
+    QFile file(xmlPath);
+    if (!file.open(QIODevice::ReadOnly))
+    {
+        return;
+    }
+    if (!doc.setContent(&file)) {
+        file.close();
+        return;
+    }
+    file.close();
 
-	// print out the element names of all elements that are direct children
-	// of the outermost element.
-	QDomElement docElem = doc.documentElement();
+    // print out the element names of all elements that are direct children
+    // of the outermost element.
+    QDomElement docElem = doc.documentElement();
 
-	QDomNode n = docElem.firstChild();
-	while(!n.isNull()) {
-		QDomElement e = n.toElement(); // try to convert the node to an element.
-		if(!e.isNull()) {
-			if (e.tagName() == "track")
-			{
-				QString filename = promoDirPath + "/" + e.text();
+    QDomNode n = docElem.firstChild();
+    while(!n.isNull()) {
+        QDomElement e = n.toElement(); // try to convert the node to an element.
+        if(!e.isNull()) {
+            if (e.tagName() == "track")
+            {
+                QString filename = promoDirPath + "/" + e.text();
                 float bpm = e.attribute("bpm").toFloat();
                 QString url = e.attribute("url");
                 //TODO: Load comment, but don't overwrite it if the track is already
@@ -411,21 +432,21 @@ void Track::loadPromoTrackXMLData(QString xmlPath, QString promoDirPath)
 
                 //Grab the track from the TrackCollection and add it's metadata...
 
-				TrackInfoObject *newTrack = m_pTrackCollection->getTrack(filename);
+                TrackInfoObject *newTrack = m_pTrackCollection->getTrack(filename);
                 if (newTrack)
                 {
                     newTrack->setBpm(bpm);
                     newTrack->setURL(url);
                     //newTrack->setComment(from XML)
-					 m_qPromoPlaylist.append(newTrack);
+                     m_qPromoPlaylist.append(newTrack);
                 }
             }
 
-		}
-		n = n.nextSibling();
-	}
+        }
+        n = n.nextSibling();
+    }
 
-	qDebug() << "Promo playlist has" << m_qPromoPlaylist.getSongNum() << "songs.";
+    qDebug() << "Promo playlist has" << m_qPromoPlaylist.getSongNum() << "songs.";
 
 }
 
@@ -614,8 +635,8 @@ void Track::slotScanLibrary()
 
     #ifdef __C_METRICS__
 
-	cm_writemsg_ascii(MIXXXCMETRICS_LIBRARY_SCAN_TIME,
-	                  baElapsed.data());
+    cm_writemsg_ascii(MIXXXCMETRICS_LIBRARY_SCAN_TIME,
+                      baElapsed.data());
     #endif
 }
 
@@ -722,8 +743,8 @@ void Track::slotActivatePlaylist(int index)
        // Enable sorting mode -- optimize me if you can!
        // TODO: Restore sort column / sort order and restore view position.
        m_pView->m_pTrackTableView->setSortingEnabled(true);
-       m_pView->m_pTrackTableView->horizontalHeader()->setSortIndicator(COL_ARTIST, Qt::AscendingOrder);
-       m_pView->m_pTrackTableView->m_pSearchFilter->sort(COL_ARTIST);
+       m_pView->m_pTrackTableView->horizontalHeader()->setSortIndicator(WTrackTableModel::ARTIST, Qt::AscendingOrder);
+       m_pView->m_pTrackTableView->m_pSearchFilter->sort(WTrackTableModel::ARTIST);
     } else if (m_pView->m_pTrackTableView->getTableMode() != TABLE_MODE_PLAYQUEUE && index == TABLE_MODE_PLAYQUEUE) {
        // Disable sorting for play queue view, so tracks can be manually ordered using drag and drop...
        // TODO: Save sort  column / sort order from sortIndicator and save view position (see how the search filterbox saves position for example implementation)
@@ -824,7 +845,11 @@ void Track::slotDeletePlaylist(QString qName)
             m_pActivePlaylist = 0;
             bActivateOtherList = true;
         }
-        m_qPlaylists.remove(list);
+#if QT_VERSION >= 0x040400
+        m_qPlaylists.removeOne(list);
+#else
+    m_qPlaylists.removeAt(m_qPlaylists.indexOf(list));
+#endif
         delete list;
     }
 
@@ -923,58 +948,80 @@ void Track::slotLoadPlayer1(TrackInfoObject * pTrackInfoObject, bool bStartFromE
     }
     else return; // empty filename
 
-    if (m_pTrackPlayer1)
-    {
-        m_pTrackPlayer1->setOverviewWidget(0);
-        m_pTrackPlayer1->setBpmControlObject(0);
-    }
-
-    m_pTrackPlayer1 = pTrackInfoObject;
+    
 
     // Update score:
-    m_pTrackPlayer1->incTimesPlayed();
+    pTrackInfoObject->incTimesPlayed();
     if (m_pActivePlaylist)
         m_pActivePlaylist->updateScores();
 
     // Request a new track from the reader:
-    m_pBuffer1->getReader()->requestNewTrack(m_pTrackPlayer1, bStartFromEndPos);
+    m_pBuffer1->getReader()->requestNewTrack(pTrackInfoObject, bStartFromEndPos);
 
+    //The rest of the track loading code gets executed in
+    //slotFinishLoadingPlayer1(), which gets called when Reader emits a signal
+    //saying it's done loading the song. This prevents several race conditions.
+}
+
+/** This slot gets called when Reader has finished loading a new track, because
+    Reader loads it in a separate thread.  This code is essentially the second
+    half of slotLoadPlayer1(), which is the stuff that needs to be executed
+    after the song has been loaded into the reader. Before this function was
+    implemented, there were a handful of race conditions in slotLoadPlayer1()
+    where stuff was executed at the same time as Reader was loading the
+    track. This function explicitly solves that problem. */
+void Track::slotFinishLoadingPlayer1(TrackInfoObject* pTrackInfoObject, bool bStartFromEndPos)
+{
     // Read the tags if required
-    if(!m_pTrackPlayer1->getHeaderParsed())
-        SoundSourceProxy::ParseHeader(m_pTrackPlayer1);
-    // Detect BPM if required
-    if (m_pTrackPlayer1->getBpmConfirm()== false || m_pTrackPlayer1->getBpm() == 0.)
-        m_pTrackPlayer1->sendToBpmQueue();
-
-    // Generate waveform summary
-    m_pTrackPlayer1->setVisualResampleRate(m_pVisualResampleCh1->get());
-    m_pWaveSummary->enqueue(m_pTrackPlayer1);
+    if(!pTrackInfoObject->getHeaderParsed())
+        SoundSourceProxy::ParseHeader(pTrackInfoObject);
 
     // Set waveform summary display
-    m_pTrackPlayer1->setOverviewWidget(m_pView->m_pOverviewCh1);
+    pTrackInfoObject->setOverviewWidget(m_pView->m_pOverviewCh1);
+    
+    // This has to happen before the AnalyserQueue works on the track.
+    pTrackInfoObject->setVisualResampleRate(m_pVisualResampleCh1->get());
 
-    // Set control for beat start position for use in EngineTemporal and
-    // VisualTemporalBuffer. HACK.
-    ControlObject * p = ControlObject::getControl(ConfigKey("[Channel1]","temporalBeatFirst"));
-    if (p)
-        p->queueFromThread(m_pTrackPlayer1->getBeatFirst());
+    // Queue the track for BPM/Waveform/Wavesummary/etc. analysis
+    m_analyserQueue->queueAnalyseTrack(pTrackInfoObject);
 
     // Set Engine file BPM and duration ControlObjects
-    m_pTrackPlayer1->setBpmControlObject(ControlObject::getControl(ConfigKey("[Channel1]","file_bpm")));
-    m_pTrackPlayer1->setDurationControlObject(ControlObject::getControl(ConfigKey("[Channel1]","duration")));
+    pTrackInfoObject->setBpmControlObject(ControlObject::getControl(ConfigKey("[Channel1]","file_bpm")));
+    pTrackInfoObject->setDurationControlObject(ControlObject::getControl(ConfigKey("[Channel1]","duration")));
+
+    // Update TrackInfoObject of the helper class
+    PlayerInfo::Instance().setTrackInfo(1, pTrackInfoObject);
+    
+    //Set the cue point, if it was saved.
+    m_pCuePointCh1->slotSet(pTrackInfoObject->getCuePoint());
+
+    //Seek to cue position if we're not starting at end of song and cue recall is on
+    if (!bStartFromEndPos) {
+        int cueRecall = m_pConfig->getValueString(ConfigKey("[Controls]","CueRecall")).toInt();
+        if (cueRecall == 0) { //If cue recall is ON in the prefs, then we're supposed to seek to the cue point on song load. 
+            //Note that cueRecall == 0 corresponds to "ON", not OFF.
+            float cue_point = pTrackInfoObject->getCuePoint();
+            long numSamplesInSong = m_pBuffer1->getReader()->getFileLength(); 
+            cue_point = cue_point / (numSamplesInSong);
+            m_pPlayPositionCh1->slotSet(cue_point);
+        }
+    }
 
     // Set duration in playpos widget
 //    if (m_pView->m_pNumberPosCh1)
-//        m_pView->m_pNumberPosCh1->setDuration(m_pTrackPlayer1->getDuration());
+//        m_pView->m_pNumberPosCh1->setDuration(pTrackInfoObject->getDuration());
 
     // Write info to text display
     if (m_pView->m_pTextCh1)
-        m_pView->m_pTextCh1->setText(m_pTrackPlayer1->getInfo());
+        m_pView->m_pTextCh1->setText(pTrackInfoObject->getInfo());
 
-    emit(newTrackPlayer1(m_pTrackPlayer1));
+    if (m_pTrackPlayer1) {
+        m_pTrackPlayer1->setOverviewWidget(0);
+        m_pTrackPlayer1->setBpmControlObject(0);
+    }    
 
-    // Update TrackInfoObject of the helper class
-    PlayerInfo::Instance().setTrackInfo(1, m_pTrackPlayer1);
+    m_pTrackPlayer1 = pTrackInfoObject;
+    emit(newTrackPlayer1(pTrackInfoObject));
 }
 
 void Track::slotLoadPlayer2(TrackInfoObject * pTrackInfoObject, bool bStartFromEndPos)
@@ -996,60 +1043,73 @@ void Track::slotLoadPlayer2(TrackInfoObject * pTrackInfoObject, bool bStartFromE
     }
     else return; // empty filename
 
-    if (m_pTrackPlayer2)
-    {
-        m_pTrackPlayer2->setOverviewWidget(0);
-        m_pTrackPlayer2->setBpmControlObject(0);
-    }
-
-    m_pTrackPlayer2 = pTrackInfoObject;
-
     // Update score:
-    m_pTrackPlayer2->incTimesPlayed();
+    pTrackInfoObject->incTimesPlayed();
     if (m_pActivePlaylist)
         m_pActivePlaylist->updateScores();
 
     // Request a new track from the reader:
-    m_pBuffer2->getReader()->requestNewTrack(m_pTrackPlayer2, bStartFromEndPos);
+    m_pBuffer2->getReader()->requestNewTrack(pTrackInfoObject, bStartFromEndPos);
+}
 
+/** See comment for slotFinishLoadingPlayer1 */
+void Track::slotFinishLoadingPlayer2(TrackInfoObject* pTrackInfoObject, bool bStartFromEndPos)
+{
     // Read the tags if required
-    if(!m_pTrackPlayer2->getHeaderParsed())
-        SoundSourceProxy::ParseHeader(m_pTrackPlayer2);
-    // Detect BPM if required
-    if (m_pTrackPlayer2->getBpmConfirm()== false || m_pTrackPlayer2->getBpm() == 0.)
-        m_pTrackPlayer2->sendToBpmQueue();
-
-    // Generate waveform summary
-    m_pTrackPlayer2->setVisualResampleRate(m_pVisualResampleCh2->get());
-    m_pWaveSummary->enqueue(m_pTrackPlayer2);
+    if(!pTrackInfoObject->getHeaderParsed())
+        SoundSourceProxy::ParseHeader(pTrackInfoObject);
 
     // Set waveform summary display
-    m_pTrackPlayer2->setOverviewWidget(m_pView->m_pOverviewCh2);
+    pTrackInfoObject->setOverviewWidget(m_pView->m_pOverviewCh2);
+    
+    // This has to happen before the AnalyserQueue works on the track.
+    pTrackInfoObject->setVisualResampleRate(m_pVisualResampleCh2->get());
 
-    // Set control for beat start position for use in EngineTemporal and
-    // VisualTemporalBuffer. HACK.
-    ControlObject * p = ControlObject::getControl(ConfigKey("[Channel2]","temporalBeatFirst"));
-    if (p)
-        p->queueFromThread(m_pTrackPlayer2->getBeatFirst());
+    // Queue the track for BPM/Waveform/Wavesummary/etc. analysis
+    m_analyserQueue->queueAnalyseTrack(pTrackInfoObject);
 
     // Set Engine file BPM ControlObject
-    m_pTrackPlayer2->setBpmControlObject(ControlObject::getControl(ConfigKey("[Channel2]","file_bpm")));
-    m_pTrackPlayer2->setDurationControlObject(ControlObject::getControl(ConfigKey("[Channel2]","duration")));
+    pTrackInfoObject->setBpmControlObject(ControlObject::getControl(ConfigKey("[Channel2]","file_bpm")));
+    pTrackInfoObject->setDurationControlObject(ControlObject::getControl(ConfigKey("[Channel2]","duration")));
+
+    // Update TrackInfoObject of the helper class
+    PlayerInfo::Instance().setTrackInfo(2, pTrackInfoObject);
+    
+    //Set the cue point, if it was saved.
+    m_pCuePointCh2->slotSet(pTrackInfoObject->getCuePoint());
+    
+    //Seek to cue position if we're not starting at end of song and cue recall is on
+    if (!bStartFromEndPos) {
+        int cueRecall = m_pConfig->getValueString(ConfigKey("[Controls]","CueRecall")).toInt();
+        if (cueRecall == 0) { //If cue recall is ON in the prefs, then we're supposed to seek to the cue point on song load. 
+            //Note that cueRecall == 0 corresponds to "ON", not OFF.
+            float cue_point = pTrackInfoObject->getCuePoint();
+            long numSamplesInSong = m_pBuffer2->getReader()->getFileLength(); 
+            cue_point = cue_point / (numSamplesInSong);
+            m_pPlayPositionCh2->slotSet(cue_point);
+        }
+    }
+
 
     // Set duration in playpos widget
 //    if (m_pView->m_pNumberPosCh2)
-//        m_pView->m_pNumberPosCh2->setDuration(m_pTrackPlayer2->getDuration());
+//        m_pView->m_pNumberPosCh2->setDuration(pTrackInfoObject->getDuration());
 
     // Write info to text display
     if (m_pView->m_pTextCh2)
-        m_pView->m_pTextCh2->setText(m_pTrackPlayer2->getInfo());
+        m_pView->m_pTextCh2->setText(pTrackInfoObject->getInfo());
 
-    emit(newTrackPlayer2(m_pTrackPlayer2));
+    if (m_pTrackPlayer2) {
+        m_pTrackPlayer2->setOverviewWidget(0);
+        m_pTrackPlayer2->setBpmControlObject(0);
+    }
+    
+    m_pTrackPlayer2 = pTrackInfoObject;
+    emit(newTrackPlayer2(pTrackInfoObject));
 
-    // Update TrackInfoObject of the helper class
-    PlayerInfo::Instance().setTrackInfo(2, m_pTrackPlayer2);
 }
 
+
 void Track::slotLoadPlayer1(QString filename, bool bStartFromEndPos)
 {
     TrackInfoObject * pTrack = m_pTrackCollection->getTrack(filename);
@@ -1079,7 +1139,8 @@ void Track::slotEndOfTrackPlayer1(double val)
     switch ((int)m_pEndOfTrackModeCh1->get())
     {
     case TRACK_END_MODE_NEXT:
-        if (m_pTrackPlayer1)
+        TrackInfoObject* currentTrack = m_pTrackPlayer1;
+        if (currentTrack)
         {
             TrackInfoObject *pTrack = NULL;
             bool bStartFromEndPos = false;
@@ -1088,7 +1149,7 @@ void Track::slotEndOfTrackPlayer1(double val)
             if (m_pPlayPositionCh1->get()>0.5)
             {
                //If the play queue has another song in it, load that...
-               int idx = m_qPlayqueuePlaylist.indexOf(m_pTrackPlayer1);
+               int idx = m_qPlayqueuePlaylist.indexOf(currentTrack);
                if (idx + 1 < m_qPlayqueuePlaylist.count())
                {
                    pTrack = m_qPlayqueuePlaylist.at(idx + 1);
@@ -1102,7 +1163,7 @@ void Track::slotEndOfTrackPlayer1(double val)
             else //Load previous track
             {
                 //If the play queue has a previous song in it, load that...
-                int idx = m_qPlayqueuePlaylist.indexOf(m_pTrackPlayer1);
+                int idx = m_qPlayqueuePlaylist.indexOf(currentTrack);
                 if (idx - 1 >= 0)
                 {
                     pTrack = m_qPlayqueuePlaylist.at(idx - 1);
@@ -1135,7 +1196,8 @@ void Track::slotEndOfTrackPlayer2(double val)
     switch ((int)m_pEndOfTrackModeCh2->get())
     {
     case TRACK_END_MODE_NEXT:
-        if (m_pTrackPlayer2)
+        TrackInfoObject* currentTrack = m_pTrackPlayer2;
+        if (currentTrack)
         {
             TrackInfoObject *pTrack = NULL;
             bool bStartFromEndPos = false;
@@ -1144,7 +1206,7 @@ void Track::slotEndOfTrackPlayer2(double val)
             if (m_pPlayPositionCh2->get()>0.5)
             {
                //If the play queue has another song in it, load that...
-               int idx = m_qPlayqueuePlaylist.indexOf(m_pTrackPlayer2);
+               int idx = m_qPlayqueuePlaylist.indexOf(currentTrack);
                if (idx + 1 < m_qPlayqueuePlaylist.count())
                {
                    pTrack = m_qPlayqueuePlaylist.at(idx + 1);
@@ -1158,7 +1220,7 @@ void Track::slotEndOfTrackPlayer2(double val)
             else //Load previous track
             {
                 //If the play queue has a previous song in it, load that...
-                int idx = m_qPlayqueuePlaylist.indexOf(m_pTrackPlayer2);
+                int idx = m_qPlayqueuePlaylist.indexOf(currentTrack);
                 if (idx - 1 >= 0)
                 {
                     pTrack = m_qPlayqueuePlaylist.at(idx - 1);
@@ -1188,9 +1250,11 @@ void Track::slotLoadSelectedTrackCh1(double v)
     if (v && m_pView->m_pTrackTableView->m_pTable) {
         // Fetch the currently selected track
         index = m_pView->m_pTrackTableView->m_pSearchFilter->mapToSource(m_pView->m_pTrackTableView->currentIndex());
+        int row = index.row();
+        if (row < 0 || row >= m_pView->m_pTrackTableView->m_pTable->m_pTrackPlaylist->size()) return; // prevent QList out-of-bounds asserts
         pTrack = m_pView->m_pTrackTableView->m_pTable->m_pTrackPlaylist->at(index.row());
-	    // If there is one, load it
-	if (pTrack) slotLoadPlayer1(pTrack);
+        // If there is one, load it
+    if (pTrack) slotLoadPlayer1(pTrack);
     }
 }
 
@@ -1203,7 +1267,7 @@ void Track::slotLoadSelectedTrackCh2(double v)
         // Fetch the currently selected track
         index = m_pView->m_pTrackTableView->m_pSearchFilter->mapToSource(m_pView->m_pTrackTableView->currentIndex());
         pTrack = m_pView->m_pTrackTableView->m_pTable->m_pTrackPlaylist->at(index.row());
-	    // If there is one, load it
+        // If there is one, load it
         if (pTrack) slotLoadPlayer2(pTrack);
     }
 }
@@ -1234,6 +1298,7 @@ void Track::slotSelectPrevTrack(double v)
 void Track::slotSelectTrackKnob(double v)
 {
     int i = (int)v;
+    m_pView->m_pTrackTableView->setUpdatesEnabled(false);
     while(i != 0)
     {
         if(i > 0)
@@ -1247,13 +1312,15 @@ void Track::slotSelectTrackKnob(double v)
             i++;
         }
     }
+    m_pView->m_pTrackTableView->setUpdatesEnabled(true);
 }
 
 void Track::slotNextTrackPlayer1(double v)
 {
-    if (v && m_pTrackPlayer1)
+    TrackInfoObject* currentTrack = m_pTrackPlayer1;
+    if (v && currentTrack)
     {
-        TrackInfoObject * pTrack = m_pTrackPlayer1->getNext(m_pActivePlaylist);
+        TrackInfoObject * pTrack = currentTrack->getNext(m_pActivePlaylist);
         if (pTrack)
             slotLoadPlayer1(pTrack);
     }
@@ -1261,9 +1328,10 @@ void Track::slotNextTrackPlayer1(double v)
 
 void Track::slotPrevTrackPlayer1(double v)
 {
-    if (v && m_pTrackPlayer1)
+    TrackInfoObject* currentTrack = m_pTrackPlayer1;
+    if (v && currentTrack)
     {
-        TrackInfoObject * pTrack = m_pTrackPlayer1->getPrev(m_pActivePlaylist);
+        TrackInfoObject * pTrack = currentTrack->getPrev(m_pActivePlaylist);
         if (pTrack)
             slotLoadPlayer1(pTrack);
     }
@@ -1271,9 +1339,10 @@ void Track::slotPrevTrackPlayer1(double v)
 
 void Track::slotNextTrackPlayer2(double v)
 {
-    if (v && m_pTrackPlayer2)
+    TrackInfoObject* currentTrack = m_pTrackPlayer2;
+    if (v && currentTrack)
     {
-        TrackInfoObject * pTrack = m_pTrackPlayer2->getNext(m_pActivePlaylist);
+        TrackInfoObject * pTrack = currentTrack->getNext(m_pActivePlaylist);
         if (pTrack)
             slotLoadPlayer2(pTrack);
     }
@@ -1281,9 +1350,10 @@ void Track::slotNextTrackPlayer2(double v)
 
 void Track::slotPrevTrackPlayer2(double v)
 {
-    if (v && m_pTrackPlayer2)
+    TrackInfoObject* currentTrack = m_pTrackPlayer2;
+    if (v && currentTrack)
     {
-        TrackInfoObject * pTrack = m_pTrackPlayer2->getPrev(m_pActivePlaylist);
+        TrackInfoObject * pTrack = currentTrack->getPrev(m_pActivePlaylist);
         if (pTrack)
             slotLoadPlayer2(pTrack);
     }
@@ -1360,32 +1430,18 @@ void Track::slotBatchBPMDetection()
       if (cur_track->getWaveSummary() == NULL || cur_track->getWaveSummary()->size() == 0) {
         processed++;
         // TODO: convert the qDebug statement to a status dialog box.
-        qDebug() << "Track #"<< i << "= Batch job #"<< processed << ":" << cur_track->getTitle() << "by" << cur_track->getArtist() << "has WaveSummary: false -- has BPM value:" << (cur_track->getBpm() > 0) << " ("<< m_pBpmDetector->queueCount() << "tracks in the BPM Detect Queue )";
-        // Open sound file
-        SoundSourceProxy * pSoundSource = new SoundSourceProxy(cur_track);
-	m_pWaveSummary->waveformSummaryGen(cur_track, pSoundSource, false);
-        delete pSoundSource;
-        pSoundSource = NULL;
+        qDebug() << "Track #"<< i << "= Batch job #"<< processed << ":" << cur_track->getTitle() << "by" << cur_track->getArtist() << "has WaveSummary: false -- has BPM value:" << (cur_track->getBpm() > 0);
 
+        // TODO(rryan) make an AnalyserQueue here
         // Batch Process BPM
-        if (cur_track->getBpm() == 0) {
-          cur_track->sendToBpmQueue();
-        }
+        //if (cur_track->getBpm() == 0) {
+        //cur_track->sendToBpmQueue();
+        //}
       }
 
       // FIXME: remove the song count limitation when BPM detect doesn't crash...
       if (processed == 100) { qDebug() << "----- BPM detection/Waveform generation batch processing limit of " << processed << " songs has been reached. Rerun to detect more songs."; break; }
     }
-    // Block the UI thread until BPM detection queue is cleared.
-    while (m_pBpmDetector->queueCount()) {
-      // TODO: convert the qDebug statement to a status dialog box.
-      qDebug() << "---- waiting for BPM detection queue to empty... " << m_pBpmDetector->queueCount() << " to go.";
-#ifdef __WIN__
-      Sleep(3000);
-#else
-      sleep(3);
-#endif
-    }
     // Save the track database to disk...
     writeXML(m_pConfig->getValueString(ConfigKey("[Playlist]","Listfile")));
 }
