@@ -23,14 +23,14 @@
 #include <Q3MemArray>
 #include <QtDebug>
 #include "trackinfoobject.h"
-#include "bpmdetector.h"
-#include "bpmscheme.h"
-#include "bpmreceiver.h"
+#include "bpm/bpmdetector.h"
+#include "bpm/bpmscheme.h"
+#include "bpm/bpmreceiver.h"
 #include "soundsourceproxy.h"
 #include "trackplaylist.h"
 //#include "wtracktable.h"
 //#include "wtracktableitem.h"
-#include "woverview.h"
+#include "widget/woverview.h"
 #include "xmlparse.h"
 #include <qdom.h>
 #include "controlobject.h"
@@ -41,8 +41,9 @@
 
 int TrackInfoObject::siMaxTimesPlayed = 1;
 
-TrackInfoObject::TrackInfoObject(const QString sPath, const QString sFile, BpmDetector * bpmDetector) : m_sFilename(sFile), m_sFilepath(sPath)
-{
+TrackInfoObject::TrackInfoObject(const QString sPath, const QString sFile) 
+	: m_sFilename(sFile), m_sFilepath(sPath),
+	m_chordData() {
     m_sArtist = "";
     m_sTitle = "";
     m_sType= "";
@@ -65,11 +66,11 @@ TrackInfoObject::TrackInfoObject(const QString sPath, const QString sFile, BpmDe
     m_pControlObjectDuration = 0;
     m_iSampleRate = 0;
     m_iChannels = 0;
+    m_fCuePoint = 0.0f;
+    m_pOverviewWidget = NULL;
 
     m_dVisualResampleRate = 0;
 
-    m_BpmDetector = bpmDetector;
-
     m_fBpmFactors = (float *)malloc(sizeof(float) * NumBpmFactors);
     generateBpmFactors();
 
@@ -100,8 +101,8 @@ TrackInfoObject::TrackInfoObject(const QString sPath, const QString sFile, BpmDe
     //qDebug() << "done constructing  TrackInfoObject....";
 }
 
-TrackInfoObject::TrackInfoObject(const QDomNode &nodeHeader, BpmDetector * bpmDetector)
-{
+TrackInfoObject::TrackInfoObject(const QDomNode &nodeHeader)
+	: m_chordData() {
     m_sFilename = XmlParse::selectNodeQString(nodeHeader, "Filename");
     m_sFilepath = XmlParse::selectNodeQString(nodeHeader, "Filepath");
     m_sTitle = XmlParse::selectNodeQString(nodeHeader, "Title");
@@ -120,12 +121,11 @@ TrackInfoObject::TrackInfoObject(const QDomNode &nodeHeader, BpmDetector * bpmDe
     m_bHeaderParsed = false;
     m_iScore = 0;
     m_iId = XmlParse::selectNodeQString(nodeHeader, "Id").toInt();
+    m_fCuePoint = XmlParse::selectNodeQString(nodeHeader, "CuePoint").toFloat();
 
     m_fBpmFactors = (float *)malloc(sizeof(float) * NumBpmFactors);
     generateBpmFactors();
 
-    m_BpmDetector = bpmDetector;
-
     m_pVisualWave = 0;
     m_dVisualResampleRate = 0;
     
@@ -210,6 +210,7 @@ void TrackInfoObject::writeToXML( QDomDocument &doc, QDomElement &header )
     XmlParse::addElement( doc, header, "BpmConfirm", QString("%1").arg(m_bBpmConfirm) );
     XmlParse::addElement( doc, header, "BeatFirst", QString("%1").arg(m_fBeatFirst) );
     XmlParse::addElement( doc, header, "Id", QString("%1").arg(m_iId) );
+    XmlParse::addElement( doc, header, "CuePoint", QString::number(m_fCuePoint) );
     if (m_pWave) {
         XmlParse::addHexElement(doc, header, "WaveSummaryHex", m_pWave);
     }
@@ -257,14 +258,14 @@ void TrackInfoObject::writeToXML( QDomDocument &doc, QDomElement &header )
     //qDebug() << "inserting.. " << pTableTrack->item(iRow;
 
     // Insert the elements into the table
-    pTableTrack->setItem(iRow, COL_SCORE, m_pTableItemScore);
-    pTableTrack->setItem(iRow, COL_TITLE, m_pTableItemTitle);
-    pTableTrack->setItem(iRow, COL_ARTIST, m_pTableItemArtist);
-    pTableTrack->setItem(iRow, COL_COMMENT, m_pTableItemComment);
-    pTableTrack->setItem(iRow, COL_TYPE, m_pTableItemType);
-    pTableTrack->setItem(iRow, COL_DURATION, m_pTableItemDuration);
-    pTableTrack->setItem(iRow, COL_BPM, m_pTableItemBpm);
-    pTableTrack->setItem(iRow, COL_BITRATE, m_pTableItemBitrate);
+    pTableTrack->setItem(iRow, WTrackTableModel::SCORE, m_pTableItemScore);
+    pTableTrack->setItem(iRow, WTrackTableModel::TITLE, m_pTableItemTitle);
+    pTableTrack->setItem(iRow, WTrackTableModel::ARTIST, m_pTableItemArtist);
+    pTableTrack->setItem(iRow, WTrackTableModel::COMMENT, m_pTableItemComment);
+    pTableTrack->setItem(iRow, WTrackTableModel::TYPE, m_pTableItemType);
+    pTableTrack->setItem(iRow, WTrackTableModel::DURATION, m_pTableItemDuration);
+    pTableTrack->setItem(iRow, WTrackTableModel::BPM, m_pTableItemBpm);
+    pTableTrack->setItem(iRow, WTrackTableModel::BITRATE, m_pTableItemBitrate);
 
     m_pTableTrack = pTableTrack;
 
@@ -340,7 +341,7 @@ void TrackInfoObject::parseFilename()
 {
     m_qMutex.lock();
 
-    if (m_sFilename.find('-') != -1)
+    if (m_sFilename.indexOf('-') != -1)
     {
         m_sArtist = m_sFilename.section('-',0,0).trimmed(); // Get the first part
         m_sTitle = m_sFilename.section('-',1,1); // Get the second part
@@ -363,7 +364,7 @@ void TrackInfoObject::parseFilename()
     m_sComment = QString("");
 
     // Find the type
-    m_sType = m_sFilename.section(".",-1).lower().trimmed();
+    m_sType = m_sFilename.section(".",-1).toLower().trimmed();
 
     m_qMutex.unlock();
 }
@@ -411,30 +412,6 @@ QString TrackInfoObject::getLocation() const
     return qLocation;
 }
 
-void TrackInfoObject::sendToBpmQueue()
-{
-    if(m_BpmDetector)
-    {
-        m_BpmDetector->enqueue(this);
-    }
-}
-
-void TrackInfoObject::sendToBpmQueue(BpmReceiver * pBpmReceiver)
-{
-    if(m_BpmDetector)
-    {
-        m_BpmDetector->enqueue(this, pBpmReceiver);
-    }
-}
-
-void TrackInfoObject::sendToBpmQueue(BpmReceiver * pBpmReceiver, BpmScheme* pScheme)
-{
-    if(m_BpmDetector)
-    {
-        m_BpmDetector->enqueue(this, pScheme, pBpmReceiver);
-    }
-}
-
 float TrackInfoObject::getBpm() const
 {
     m_qMutex.lock();
@@ -953,3 +930,15 @@ QString TrackInfoObject::getURL()
 {
     return m_sURL;
 }
+
+void TrackInfoObject::setCuePoint(float cue)
+{
+    m_qMutex.lock();
+    m_fCuePoint = cue;
+    m_qMutex.unlock();
+}
+
+float TrackInfoObject::getCuePoint()
+{
+    return m_fCuePoint;
+}
