@@ -39,6 +39,9 @@ class BpmReceiver;
 class BpmScheme;
 class TrackPlaylist;
 
+//template <class T> class Segmentation;
+#include "segmentation.h"
+
 #define NumBpmFactors 4
 
 const float Factors[NumBpmFactors]={0.33, 0.5, 2, 0.25};
@@ -48,9 +51,9 @@ class TrackInfoObject : public QObject
     Q_OBJECT
 public:
     /** Initialize a new track with the filename. */
-    TrackInfoObject(const QString sPath, const QString sFile, BpmDetector *bpmDetector);
+    TrackInfoObject(const QString sPath, const QString sFile);
     /** Creates a new track given information from the xml file. */
-    TrackInfoObject(const QDomNode &, BpmDetector *bpmDetector);
+    TrackInfoObject(const QDomNode &);
     ~TrackInfoObject();
     /** Returns true if the object contains valid information */
     bool isValid() const;
@@ -72,10 +75,6 @@ public:
     QString getDurationStr() const;
     /** Returns the location of the file, included path */
     QString getLocation() const;
-    /** Add this TrackInfoObject instance to the BPM detection queue */
-    void sendToBpmQueue();
-    void sendToBpmQueue(BpmReceiver *pBpmReceiver);
-    void sendToBpmQueue(BpmReceiver *pBpmReceiver, BpmScheme *pScheme);
     /** Returns BPM */
     float getBpm() const;
     /** Set BPM */
@@ -183,6 +182,16 @@ public:
     /** Set pointer to ControlObject holding duration value in engine */
     void setDurationControlObject(ControlObject *p);
 	QString getFilepath() const;
+    /** Save the cue point (in samples... I think) */
+    void setCuePoint(float cue);
+    /** Get saved the cue point */
+    float getCuePoint();
+
+	const Segmentation<QString>* getChordData() { return &m_chordData; }
+	void setChordData(Segmentation<QString> cd) {
+		m_chordData = cd; 
+	}
+
 private:
     /** Method for parsing information from knowing only the file name.
         It assumes that the filename is written like: "artist - trackname.xxx" */
@@ -233,6 +242,8 @@ private:
     int m_iScore;
     /** Id. Unique ID of track */
     int m_iId;
+    /** Cue point in samples or something */
+    float m_fCuePoint;
 
     /** Pointer to visual waveform info */
     QVector<float> *m_pVisualWave;
@@ -262,8 +273,7 @@ private:
     int iTemp;
     double m_dVisualResampleRate;
 
-    /** Bpm Detection Queue */
-    BpmDetector *m_BpmDetector;
+	Segmentation<QString> m_chordData;
 };
 
 #endif
