@@ -6,11 +6,12 @@
 #include <QDomNode>
 
 #include "configobject.h"
-#include "wwidget.h"
+#include "widget/wwidget.h"
 
 class WVisualSimple;
 class WWaveformViewer;
 class WGLWaveformViewer;
+class WaveformRenderer;
 
 enum WaveformViewerType {
     WAVEFORM_SIMPLE=0,
@@ -31,7 +32,7 @@ private:
     static QList<WGLWaveformViewer*> m_visualGLViewers;
 
 public:
-    static WaveformViewerType createWaveformViewer(const char* group, QWidget *pParent, ConfigObject<ConfigValue> *pConfig, QObject **target);
+    static WaveformViewerType createWaveformViewer(const char* group, QWidget *pParent, ConfigObject<ConfigValue> *pConfig, QObject **target, WaveformRenderer *pWaveformRenderer);
     static void destroyWaveformViewer(QObject *pWaveformViewer);
     static WaveformViewerType getWaveformViewerType(QObject *pWaveformViewer);
     
